@@ -1,9 +1,7 @@
 /*
-  $Id: GetOptClass.h 17566 2014-08-26 08:27:38Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/GetOptClass.h $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
 
   This file is part of timbl
@@ -22,9 +20,10 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 #ifndef TIMBL_GETOPTCLASS_H
 #define TIMBL_GETOPTCLASS_H
@@ -32,18 +31,15 @@
 #include <list>
 #include <iosfwd>
 
-#include "Types.h"
-
 namespace Timbl {
-  class CL_Options;
   class TimblExperiment;
 
   class GetOptClass: public MsgClass {
   public:
-    GetOptClass( CL_Options&  );
+    GetOptClass( const TiCC::CL_Options&  );
     virtual ~GetOptClass();
     GetOptClass *Clone( std::ostream * = 0 ) const;
-    bool parse_options( const CL_Options&, const int=0 );
+    bool parse_options( const TiCC::CL_Options&, const int=0 );
     void set_default_options( const int=0 );
     bool definitive_options( TimblExperiment * );
     AlgorithmType Algo() const { return local_algo; };
