@@ -1,11 +1,9 @@
 /*
-  $Id: Matrices.h 16820 2014-01-06 10:12:30Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/Matrices.h $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
- 
+
   This file is part of timbl
 
   timbl is free software; you can redistribute it and/or modify
@@ -22,9 +20,10 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 #ifndef TIMBL_MATRICES_H
@@ -43,15 +42,15 @@ class SparseSymetricMatrix {
 
  public:
   void Clear() { my_mat.clear(); };
-  void Assign( Class i, Class j, double d ){ 
+  void Assign( Class i, Class j, double d ){
     if ( i == j )
       return;
     if ( i <j )
-      my_mat[j][i] = d; 
+      my_mat[j][i] = d;
       else
-	my_mat[i][j] = d; 
+	my_mat[i][j] = d;
   };
-  double Extract( Class i, Class j ) const { 
+  double Extract( Class i, Class j ) const {
     if ( i == j ){
       return 0.0;
     }
@@ -60,7 +59,7 @@ class SparseSymetricMatrix {
       if ( it1 != my_mat.end() ){
 	typename CDmap::const_iterator it2 = it1->second.find(i);
 	if ( it2 != it1->second.end() ){
-	  return it2->second; 
+	  return it2->second;
 	}
       }
     }
@@ -69,7 +68,7 @@ class SparseSymetricMatrix {
       if ( it1 != my_mat.end() ){
 	typename CDmap::const_iterator it2 = it1->second.find(j);
 	if ( it2 != it1->second.end() ){
-	  return it2->second; 
+	  return it2->second;
 	}
       }
     }
@@ -119,7 +118,7 @@ inline std::ostream& operator << (std::ostream& os,
     }
     ++it1;
   }
-  return os; 
+  return os;
 }
 
 #endif // TIMBL_MATRICES_H
