@@ -1,11 +1,9 @@
 /*
-  $Id: Metrics.h 16820 2014-01-06 10:12:30Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/Metrics.h $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
- 
+
   This file is part of timbl
 
   timbl is free software; you can redistribute it and/or modify
@@ -22,21 +20,22 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 #ifndef TIMBL_METRICS_H
 #define TIMBL_METRICS_H
 
-#include <limits> 
+#include <limits>
 
 namespace Timbl{
 
+  class FeatureValue;
+
   extern const double maxSimilarity;
-  
-  metricClass *getMetricClass( MetricType );
 
   class metricClass {
   public:
@@ -46,12 +45,14 @@ namespace Timbl{
     virtual bool isSimilarityMetric() const = 0;
     virtual bool isNumerical() const = 0;
     virtual bool isStorable() const = 0;
-    virtual double distance( FeatureValue *, FeatureValue *, 
+    virtual double distance( FeatureValue *, FeatureValue *,
 			     size_t=1, double = 1.0 ) const = 0;
   private:
     MetricType _type;
   };
 
+  metricClass *getMetricClass( MetricType );
+
   class distanceMetricClass: public metricClass {
   public:
   distanceMetricClass( MetricType m ): metricClass(m){};
@@ -66,7 +67,7 @@ namespace Timbl{
     bool isStorable() const { return false; };
     double distance( FeatureValue *, FeatureValue *, size_t, double ) const;
   };
-  
+
   class NumericMetricClass: public distanceMetricClass {
   public:
   NumericMetricClass( MetricType m ): distanceMetricClass( m ){};
@@ -94,7 +95,7 @@ namespace Timbl{
     bool isStorable() const { return true; };
     double distance( FeatureValue *, FeatureValue *, size_t, double ) const;
   };
-  
+
   class DiceMetric: public distanceMetricClass {
   public:
   DiceMetric(): distanceMetricClass( Dice ){};
@@ -148,6 +149,6 @@ namespace Timbl{
     double distance( FeatureValue *, FeatureValue *, size_t, double ) const;
   };
 
-}  
+}
 
 #endif // TIMBL_METRICS_H
