@@ -1,11 +1,9 @@
 /*
-  $Id: StringOps.h 16820 2014-01-06 10:12:30Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/StringOps.h $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
- 
+
   This file is part of timbl
 
   timbl is free software; you can redistribute it and/or modify
@@ -22,9 +20,10 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 #ifndef TIMBL_STRING_OPS_H
@@ -37,17 +36,16 @@
 #include <stdexcept>
 
 namespace Timbl {
-  
-  std::string string_tok( const std::string&, 
-			  std::string::size_type&,
-			  const std::string& );
-  
+
   bool compare_nocase( const std::string&, const std::string& );
   bool compare_nocase_n( const std::string&, const std::string& );
-  
+
   std::string StrToCode( const std::string& );
   std::string CodeToStr( const std::string& );
-  
+
+  std::string correct_path( const std::string&,
+			    const std::string&,
+			    bool = true );
 }
 
 #endif
