@@ -1,11 +1,9 @@
 /*
-  $Id: Testers.h 16820 2014-01-06 10:12:30Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/Testers.h $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
- 
+
   This file is part of timbl
 
   timbl is free software; you can redistribute it and/or modify
@@ -22,9 +20,10 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 #ifndef TIMBL_TESTERS_H
@@ -34,8 +33,8 @@ namespace Timbl{
   class metricTestFunction {
   public:
     virtual ~metricTestFunction(){};
-    virtual double test( FeatureValue *, 
-			 FeatureValue *, 
+    virtual double test( FeatureValue *,
+			 FeatureValue *,
 			 Feature * ) const = 0;
   };
 
@@ -55,14 +54,14 @@ namespace Timbl{
   protected:
     int threshold;
   };
-  
+
   class TesterClass {
   public:
-    TesterClass( const std::vector<Feature*>&, 
+    TesterClass( const std::vector<Feature*>&,
 		 const std::vector<size_t> & );
     virtual ~TesterClass(){};
     void init( const Instance&, size_t, size_t );
-    virtual size_t test( std::vector<FeatureValue *>&, 
+    virtual size_t test( std::vector<FeatureValue *>&,
 			 size_t,
 			 double ) = 0;
     virtual double getDistance( size_t ) const = 0;
@@ -75,60 +74,75 @@ namespace Timbl{
     std::vector<Feature *> permFeatures;
     const std::vector<size_t> &permutation;
     std::vector<double> distances;
+  private:
+    TesterClass( const TesterClass& ); // inhibit copies
+    TesterClass& operator=( const TesterClass& ); // inhibit copies
   };
-  
+
   class DistanceTester: public TesterClass {
   public:
-    DistanceTester( const std::vector<Feature*>&, 
+    DistanceTester( const std::vector<Feature*>&,
 		    const std::vector<size_t>&,
 		    int );
     ~DistanceTester();
     double getDistance( size_t ) const;
-    size_t test( std::vector<FeatureValue *>&, 
+    size_t test( std::vector<FeatureValue *>&,
 		 size_t,
-		 double ); 
+		 double );
   private:
+    DistanceTester( const DistanceTester& ); // inhibit copies
+    DistanceTester& operator=( const DistanceTester& ); // inhibit copies
     metricTestFunction **metricTest;
 
   };
-  
+
   class SimilarityTester: public TesterClass {
   public:
   SimilarityTester( const std::vector<Feature*>& pf,
-		    const std::vector<size_t>& p ): 
+		    const std::vector<size_t>& p ):
     TesterClass( pf, p ){};
     ~SimilarityTester() {};
     double getDistance( size_t ) const;
-    virtual size_t test( std::vector<FeatureValue *>&, 
+    virtual size_t test( std::vector<FeatureValue *>&,
 			 size_t,
 			 double ) = 0;
+  private:
+    SimilarityTester( const SimilarityTester & ); // inhibit copies
+    SimilarityTester& operator=( const SimilarityTester & ); // inhibit copies
   };
-  
+
   class CosineTester: public SimilarityTester {
   public:
   CosineTester( const std::vector<Feature*>& pf,
-		const std::vector<size_t>& p ): 
-    SimilarityTester( pf, p ){};  
-    size_t test( std::vector<FeatureValue *>&, 
+		const std::vector<size_t>& p ):
+    SimilarityTester( pf, p ){};
+    size_t test( std::vector<FeatureValue *>&,
 		 size_t,
 		 double );
+  private:
+    CosineTester( const CosineTester & ); // inhibit copies
+    CosineTester& operator=( const CosineTester & ); // inhibit copies
   };
-  
+
   class DotProductTester: public SimilarityTester {
   public:
   DotProductTester( const std::vector<Feature*>& pf,
-		    const std::vector<size_t>& p ): 
-    SimilarityTester( pf, p ){};  
-    size_t test( std::vector<FeatureValue *>&, 
+		    const std::vector<size_t>& p ):
+    SimilarityTester( pf, p ){};
+    size_t test( std::vector<FeatureValue *>&,
 		 size_t,
 		 double );
+  private:
+    DotProductTester( const DotProductTester & ); // inhibit copies
+    DotProductTester& operator=( const DotProductTester & ); // inhibit copies
+
   };
 
   TesterClass* getTester( MetricType,
-			  const std::vector<Feature*>&, 
+			  const std::vector<Feature*>&,
 			  const std::vector<size_t>&,
 			  int );
 
-}  
+}
 
 #endif // TIMBL_TESTERS_H
