@@ -1,9 +1,7 @@
 /*
-  $Id: TimblAPI.h 17567 2014-08-26 12:13:53Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/TimblAPI.h $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
 
   This file is part of timbl
@@ -22,9 +20,10 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 #ifndef TIMBL_API_H
@@ -32,15 +31,13 @@
 
 #include <string>
 #include <vector>
+#include "ticcutils/CommandLine.h"
 #include "timbl/Common.h"
 #include "timbl/MsgClass.h"
 #include "timbl/Types.h"
-#include "timbl/Options.h"
-#include "timbl/CommandLine.h"
 #include "timbl/Instance.h"
 #include "timbl/neighborSet.h"
 #include "timbl/TimblExperiment.h"
-#include "ticcutils/CommandLine.h"
 
 namespace Timbl{
 
@@ -51,31 +48,9 @@ namespace Timbl{
   enum Algorithm { UNKNOWN_ALG, IB1, IB2, IGTREE, TRIBL, TRIBL2, LOO, CV };
   enum Weighting { UNKNOWN_W, UD, NW, GR, IG, X2, SV, SD };
 
-  class TimblOpts {
-    friend class TimblAPI;
-    friend std::ostream& operator<<( std::ostream&, const TimblOpts&  );
-  public:
-    TimblOpts( const int, const char * const * );
-    TimblOpts( const std::string& );
-    ~TimblOpts();
-    bool Find( char, std::string&, bool& ) const;
-    bool Find( const std::string&, std::string& ) const;
-    bool Find( const std::string&, std::string&, bool& ) const;
-    void Add( char, const std::string&, bool );
-    void Add( const std::string&, const std::string& );
-    bool Delete( char );
-    bool Delete( const std::string& );
-    CL_Options *getPimpl()const { return pimpl; };
-  private:
-    CL_Options *pimpl;
-    TimblOpts( const TimblOpts& );
-    TimblOpts& operator=( const TimblOpts& );
-  };
-
   class TimblAPI {
     friend class TimblExperiment;
   public:
-    TimblAPI( const TimblOpts *, const std::string& = "" );
     TimblAPI( const TiCC::CL_Options&, const std::string& = "" );
     TimblAPI( const std::string&,  const std::string& = "" );
     TimblAPI( const TimblAPI& );
@@ -86,9 +61,10 @@ namespace Timbl{
     bool StartMultiServer( const std::string& );
     TimblExperiment *grabAndDisconnectExp(){
       TimblExperiment *res = 0;
-      if ( Valid() )
+      if ( Valid() ){
 	res = pimpl;
-      pimpl = 0;
+	pimpl = 0;
+      }
       return res;
     }
     bool Prepare( const std::string& = "" );
@@ -145,7 +121,7 @@ namespace Timbl{
     bool ShowIBInfo( std::ostream& ) const;
     bool ShowStatistics( std::ostream& ) const;
     bool SetOptions( const std::string& );
-    bool SetIndirectOptions( const TimblOpts&  );
+    bool SetIndirectOptions( const TiCC::CL_Options&  );
     bool SetThreads( int c );
     Algorithm Algo() const;
     InputFormatType getInputFormat() const;
