@@ -1,9 +1,7 @@
 /*
-  $Id: TimblExperiment.h 16820 2014-01-06 10:12:30Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/TimblExperiment.h $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
 
   This file is part of timbl
@@ -22,9 +20,10 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 #ifndef TIMBL_EXPERIMENT_H
@@ -34,20 +33,38 @@
 #include <fstream>
 #include <set>
 #include "ticcutils/XMLtools.h"
-#include "timbl/BestArray.h"
 #include "timbl/Statistics.h"
+#include "timbl/MsgClass.h"
 #include "timbl/MBLClass.h"
 
+namespace TiCC {
+  class CL_Options;
+}
+
 namespace Timbl {
 
+  extern const std::string timbl_short_opts;
+  extern const std::string timbl_long_opts;
+  extern const std::string timbl_serv_short_opts;
+  extern const std::string timbl_indirect_opts;
+
   class TimblAPI;
   class ConfusionMatrix;
-  class CL_Options;
   class GetOptClass;
+  class TargetValue;
+  class Instance;
 
   class resultStore: public MsgClass {
   public:
-  resultStore(): dist(0), disposable(false), isTop(false), beam(0) {};
+  resultStore(): rawDist(0),
+      dist(0),
+      disposable(false),
+      isTop(false),
+      beam(0),
+      norm(unknownNorm),
+      factor(0.0),
+      targets(0)
+	{};
     ~resultStore();
     bool reset( int, normType, double, const Target * );
     void clear();
@@ -62,6 +79,8 @@ namespace Timbl {
       return dist->Confidence( tv );
     };
   private:
+    resultStore( const resultStore& ); // inhibit copies
+    resultStore& operator=( const resultStore& ); // inhibit copies
     const ValueDistribution *rawDist;
     WValueDistribution *dist;
     bool disposable;
@@ -128,8 +147,8 @@ namespace Timbl {
     TimblExperiment *splitChild() const;
     bool SetOptions( int, const char ** );
     bool SetOptions( const std::string& );
-    bool SetOptions( const CL_Options&  );
-    bool IndirectOptions( const CL_Options&  );
+    bool SetOptions( const TiCC::CL_Options&  );
+    bool IndirectOptions( const TiCC::CL_Options&  );
     bool ConfirmOptions();
     bool DefaultOptions();
     GetOptClass *getOptParams() const { return OptParams; };
@@ -318,9 +337,8 @@ namespace Timbl {
   class CV_Experiment: public IB1_Experiment {
   public:
   CV_Experiment( int N = DEFAULT_MAX_FEATS, const std::string& s = "" ):
-    IB1_Experiment( N, s ), NumOfFiles( 0 ), FileNames( NULL )
+    IB1_Experiment( N, s )
       { };
-    ~CV_Experiment(){ delete [] FileNames; };
     bool Learn( const std::string& = "", bool = true );
     bool Prepare( const std::string& = "", bool = true, bool = false );
     bool Test( const std::string&,
@@ -335,8 +353,7 @@ namespace Timbl {
   private:
     CV_Experiment( const CV_Experiment& );
     CV_Experiment& operator=( const CV_Experiment& );
-    int NumOfFiles;
-    std::string *FileNames;
+    std::vector<std::string> FileNames;
     std::string CV_WfileName;
     std::string CV_PfileName;
     WeightType CV_fileW;
