@@ -1,11 +1,9 @@
 /*
-  $Id: neighborSet.h 16820 2014-01-06 10:12:30Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/neighborSet.h $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
- 
+
   This file is part of timbl
 
   timbl is free software; you can redistribute it and/or modify
@@ -22,9 +20,10 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 #ifndef TIMBL_NEIGHBORSET_H
@@ -43,28 +42,28 @@ namespace Timbl{
     double alpha;
     double beta;
   };
-  
+
   class zeroDecay: public decayStruct {
   public:
     zeroDecay():decayStruct(){};
     std::ostream& put( std::ostream& ) const;
     DecayType type() const { return Zero;};
   };
-  
+
   class invLinDecay: public decayStruct {
   public:
     invLinDecay():decayStruct(){};
     std::ostream& put( std::ostream& ) const;
     DecayType type() const { return InvLinear;};
   };
-  
+
   class invDistDecay: public decayStruct {
   public:
     invDistDecay():decayStruct(){};
     std::ostream& put( std::ostream& ) const;
     DecayType type() const { return InvDist;};
   };
-  
+
   class expDecay: public decayStruct {
   public:
     expDecay( double alp ): decayStruct(alp,1.0){};
@@ -72,7 +71,7 @@ namespace Timbl{
     std::ostream& put( std::ostream& ) const;
     DecayType type() const { return ExpDecay;};
   };
-  
+
   class neighborSet {
     friend std::ostream& operator<<( std::ostream&, const neighborSet& );
     friend std::ostream& operator<<( std::ostream&, const neighborSet * );
@@ -93,12 +92,12 @@ namespace Timbl{
     WValueDistribution *bestDistribution( const decayStruct * =0,
 					  size_t =0 ) const ;
     double relativeWeight( const decayStruct *, size_t ) const;
-    bool setShowDistance( bool b ) const { 
+    bool setShowDistance( bool b ) const {
       bool ret = showDistance;
       showDistance = b;
       return ret;
     }
-    bool setShowDistribution( bool b ) const { 
+    bool setShowDistribution( bool b ) const {
       bool ret = showDistribution;
       showDistribution = b;
       return ret;
@@ -109,7 +108,7 @@ namespace Timbl{
     void push_back( double, const ValueDistribution & );
     std::vector<double> distances;
     std::vector<ValueDistribution *> distributions;
-  };  
-  
+  };
+
 }
 #endif
