@@ -1,11 +1,9 @@
 /*
-  $Id: BestArray.cxx 16820 2014-01-06 10:12:30Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/BestArray.cxx $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
- 
+
   This file is part of timbl
 
   timbl is free software; you can redistribute it and/or modify
@@ -22,9 +20,9 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
 */
 #include <exception>
 #include <stdexcept>
@@ -41,22 +39,22 @@
 
 namespace Timbl {
   using namespace std;
-  using namespace TiCC;
   using namespace Common;
 
   BestRec::BestRec():
     bestDistance( 0.0 )
   {}
-  
+
   BestRec::~BestRec(){
-    for ( unsigned int i=0; i < bestDistributions.size(); ++i ){
-      delete bestDistributions[i];
+    for ( auto const& b : bestDistributions ){
+      delete b;
     }
   }
 
   BestArray::~BestArray(){
-    for ( unsigned int i=0; i < bestArray.size(); ++i )
-      delete bestArray[i];
+    for ( auto const& b : bestArray ){
+      delete b;
+    }
   }
 
   ostream& operator<< ( ostream& os, const BestRec *b ){
@@ -73,9 +71,9 @@ namespace Timbl {
     }
     return os;
   }
-  
-  void BestArray::init( unsigned int numN, unsigned int maxB, 
-			bool storeI, bool showDi, bool showDb ){ 
+
+  void BestArray::init( unsigned int numN, unsigned int maxB,
+			bool storeI, bool showDi, bool showDb ){
     _storeInstances = storeI;
     _showDi = showDi;
     _showDb = showDb;
@@ -92,26 +90,27 @@ namespace Timbl {
 	bestArray.push_back( new BestRec() );
       }
     }
-    for ( size_t i = 0; i < size; ++i ) {
-      bestArray[i]->bestDistance = (DBL_MAX - numN) + i;
-      if ( bestArray[i]->bestInstances.empty() ){
+    size_t penalty = 0;
+    for ( const auto& best : bestArray ){
+      best->bestDistance = (DBL_MAX - numN) + penalty++;
+      if ( best->bestInstances.empty() ){
 	if ( _storeInstances ){
-	  bestArray[i]->bestInstances.reserve( maxBests );
-	  bestArray[i]->bestDistributions.reserve( maxBests );
+	  best->bestInstances.reserve( maxBests );
+	  best->bestDistributions.reserve( maxBests );
 	}
       }
       else {
-	for ( size_t j = 0; j < bestArray[i]->bestInstances.size(); ++j ){
-	  delete bestArray[i]->bestDistributions[j];
+	for ( auto const& bd : best->bestDistributions ){
+	  delete bd;
 	}
-	bestArray[i]->bestInstances.clear();
-	bestArray[i]->bestDistributions.clear();
+	best->bestInstances.clear();
+	best->bestDistributions.clear();
       }
-      bestArray[i]->aggregateDist.clear();
+      best->aggregateDist.clear();
     }
   }
-  
-  double BestArray::addResult( double Distance, 
+
+  double BestArray::addResult( double Distance,
 			       const ValueDistribution *Distr,
 			       const string& neighbor ){
     // We have the similarity in Distance, and a num_of_neighbors
@@ -139,7 +138,7 @@ namespace Timbl {
 	0       2             3
 	1       4             2
 	2       6             1
-	
+
 	sim = 1 (dus beste)
       */
       else if (Distance < best->bestDistance) {
@@ -159,14 +158,14 @@ namespace Timbl {
 	  }
 	  best->aggregateDist.clear();
 	  best->aggregateDist.Merge( *Distr );
-	} 
+	}
 	else {
 	  //
 	  // Insert. First shift the rest up.
 	  //
 	  BestRec *keep = bestArray[size-1];
 	  for ( size_t i = size - 1; i > k; i--) {
-	    bestArray[i] = bestArray[i-1]; 
+	    bestArray[i] = bestArray[i-1];
 	  } // i
 	  //
 	  // And now insert.
@@ -189,55 +188,69 @@ namespace Timbl {
       } // Distance < fBest
     } // k
     return bestArray[size-1]->bestDistance;
-  }    
-  
+  }
+
   void BestArray::initNeighborSet( neighborSet& ns ) const {
     ns.clear();
-    for ( unsigned int k = 0; k < size; ++k ) {
-      ns.push_back( bestArray[k]->bestDistance, 
-		    bestArray[k]->aggregateDist );
+    for ( auto const& best : bestArray ){
+      ns.push_back( best->bestDistance,
+		    best->aggregateDist );
     }
   }
 
   void BestArray::addToNeighborSet( neighborSet& ns, size_t n ) const {
-    ns.push_back( bestArray[n-1]->bestDistance, 
+    ns.push_back( bestArray[n-1]->bestDistance,
 		  bestArray[n-1]->aggregateDist );
   }
 
   xmlNode *BestArray::toXML() const {
-    xmlNode *top = XmlNewNode( "neighborset" );
-    for ( unsigned int k = 0; k < size; ++k ) {
-      BestRec *best = bestArray[k];
+    xmlNode *top = TiCC::XmlNewNode( "neighborset" );
+    size_t k = 0;
+    for ( auto const& best : bestArray ){
+      ++k;
       if ( _storeInstances ){
 	size_t totalBests = best->totalBests();
 	if ( totalBests == 0 )
 	  break; // TRIBL algorithms do this!
-	xmlNode *nbs = XmlNewChild( top, "neighbors" );
-	XmlSetAttribute( nbs, "k", toString(k+1) );
-	XmlSetAttribute( nbs, "total", toString(totalBests) );
-	XmlSetAttribute( nbs, "distance", toString( best->bestDistance ) );
+	xmlNode *nbs = TiCC::XmlNewChild( top, "neighbors" );
+	TiCC::XmlSetAttribute( nbs,
+			       "k",
+			       TiCC::toString(k) );
+	TiCC::XmlSetAttribute( nbs,
+			       "total",
+			       TiCC::toString(totalBests) );
+	TiCC::XmlSetAttribute( nbs,
+			       "distance",
+			       TiCC::toString( best->bestDistance ) );
 	if ( maxBests < totalBests )
-	  XmlSetAttribute( nbs, "limited", toString( maxBests ) );
+	  TiCC::XmlSetAttribute( nbs,
+				 "limited",
+				 TiCC::toString( maxBests ) );
 	for ( unsigned int m=0; m < best->bestInstances.size(); ++m ){
-	  xmlNode *nb = XmlNewChild( nbs, "neighbor" );
-	  XmlNewTextChild( nb, "instance", best->bestInstances[m] );
+	  xmlNode *nb = TiCC::XmlNewChild( nbs, "neighbor" );
+	  TiCC::XmlNewTextChild( nb,
+				 "instance",
+				 best->bestInstances[m] );
 	  if ( _showDb )
-	    XmlNewTextChild( nb, "distribution", 
-			     best->bestDistributions[m]->DistToString() );
+	    TiCC::XmlNewTextChild( nb,
+				   "distribution",
+				   best->bestDistributions[m]->DistToString() );
 	}
       }
-      else { 
+      else {
 	if ( best->aggregateDist.ZeroDist() )
 	  break;
-	xmlNode *nbs = XmlNewChild( top, "neighbors" );
-	XmlSetAttribute( nbs, "k", toString(k+1) );
+	xmlNode *nbs = TiCC::XmlNewChild( top, "neighbors" );
+	TiCC::XmlSetAttribute( nbs, "k", TiCC::toString(k) );
 	if ( _showDb ){
-	  XmlNewTextChild( nbs, "distribution", 
-			   best->aggregateDist.DistToString() );
+	  TiCC::XmlNewTextChild( nbs,
+				 "distribution",
+				 best->aggregateDist.DistToString() );
 	}
 	if ( _showDi ){
-	  XmlNewTextChild( nbs, "distance", 
-			   toString(best->bestDistance) );
+	  TiCC::XmlNewTextChild( nbs,
+				 "distance",
+				 TiCC::toString(best->bestDistance) );
 	}
       }
     }
@@ -245,13 +258,14 @@ namespace Timbl {
   }
 
   ostream& operator<< ( ostream& os, const BestArray& bA ){
-    for ( unsigned int k = 0; k < bA.size; ++k ) {
-      BestRec *best = bA.bestArray[k];
+    size_t k = 0;
+    for ( auto const& best : bA.bestArray ){
+      ++k;
       if ( bA._storeInstances ){
 	size_t totalBests = best->totalBests();
 	if ( totalBests == 0 )
 	  break; // TRIBL algorithms do this!
-	os << "# k=" << k+1 << ", " << totalBests 
+	os << "# k=" << k << ", " << totalBests
 	   <<  " Neighbor(s) at distance: ";
 	int OldPrec = os.precision(DBL_DIG-1);
 	os.setf(ios::showpoint);
@@ -268,17 +282,17 @@ namespace Timbl {
 	    os << " -*-" << endl;
 	}
       }
-      else { 
+      else {
 	if ( best->aggregateDist.ZeroDist() )
 	  break;
-	os << "# k=" << k+1;
+	os << "# k=" << k << "\t";
 	if ( bA._showDb ){
-	  os << "\t" << best->aggregateDist.DistToString();
+	  os << best->aggregateDist.DistToString();
 	}
 	if ( bA._showDi ){
 	  int OldPrec = os.precision(DBL_DIG-1);
 	  os.setf(ios::showpoint);
-	  os << "\t" << best->bestDistance;
+	  os << best->bestDistance;
 	  os.precision(OldPrec);
 	}
 	os << endl;
