@@ -1,11 +1,9 @@
 /*
-  $Id: CVExperiment.cxx 16820 2014-01-06 10:12:30Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/CVExperiment.cxx $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
- 
+
   This file is part of timbl
 
   timbl is free software; you can redistribute it and/or modify
@@ -22,9 +20,9 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
 */
 
 
@@ -40,16 +38,8 @@
 #include "timbl/MsgClass.h"
 #include "timbl/Common.h"
 #include "timbl/Types.h"
-#include "timbl/Options.h"
-#include "timbl/Instance.h"
-#include "timbl/Statistics.h"
-#include "timbl/neighborSet.h"
-#include "timbl/BestArray.h"
-#include "timbl/IBtree.h"
-#include "timbl/MBLClass.h"
 #include "timbl/TimblExperiment.h"
 
-using namespace TiCC;
 namespace Timbl {
   using namespace std;
 
@@ -57,7 +47,7 @@ namespace Timbl {
     cerr << "CV prepare " << f << endl;
     return true;
   }
-  
+
   bool CV_Experiment::CVprepare( const string& wgtFile,
 				 WeightType w,
 				 const string& probFile ){
@@ -84,86 +74,52 @@ namespace Timbl {
     }
     return true;
   }
-  
+
   bool CV_Experiment::get_file_names( const string& FileName ){
-    bool result = false;
     if ( !ExpInvalid() ){
-      NumOfFiles = 0;
-      ifstream file_names( FileName.c_str(), ios::in );
+      size_t size = 0;
+      ifstream file_names( FileName, ios::in );
+      if ( !file_names ){
+	Error( "Unable to read CV filenames from " + FileName );
+	return false;
+      }
       string name;
-      if ( file_names.good() ) {
-	while ( getline( file_names, name ) )
-	  ++NumOfFiles;
-	file_names.close();
-	FileNames = new string[NumOfFiles];
-	ifstream file_names2( FileName.c_str(), ios::in );
-	size_t size = 0;
-	int pos = 0;
-	while ( getline( file_names2, name ) ){
-	  size_t tmp = examineData( name );
-	  if ( tmp != 0 ){
-	    if ( !Verbosity(SILENT) ){
-	      *mylog << "Examine datafile '" << FileName 
-		     << "' gave the following results:"
-		     << endl
-		     << "Number of Features: " << tmp << endl;
-	      showInputFormat( *mylog );
-	    }
-	    FileNames[pos++] = name;
-	    if ( size == 0 )
-	      size = tmp;
-	    else
-	      if ( tmp != size ) {
-		Error( "mismatching number of features in file " +
-		       name + "of CV filelist " + FileName );
-		return false;
-	      }
+      while ( getline( file_names, name ) ){
+	size_t tmp = examineData( name );
+	if ( tmp != 0 ){
+	  if ( !Verbosity(SILENT) ){
+	    *mylog << "Examine datafile '" << name
+		   << "' gave the following results:"
+		   << endl
+		   << "Number of Features: " << tmp << endl;
+	    showInputFormat( *mylog );
 	  }
+	  FileNames.push_back(name);
+	  if ( size == 0 )
+	    size = tmp;
 	  else
-	    return false;
+	    if ( tmp != size ) {
+	      Error( "mismatching number of features in file " +
+		     name + "of CV filelist " + FileName );
+	      return false;
+	    }
 	}
-	if ( pos != NumOfFiles ){
-	  Error( "Unable to read all " + toString<int>(NumOfFiles) + 
-		 " CV filenames from " + FileName );
+	else {
+	  Error( "unable to determine number of features in file " +
+		 name + "of CV filelist " + FileName );
 	  return false;
 	}
-	else
-	  result = true;
       }
-      else
-	Error( "Unable to read CV filenames from " + FileName );
+      if ( FileNames.size() < 3 ){
+	Error( "Not enough filenames found in CV filelist " + FileName
+	       + " at least 3 required" );
+	return false;
+      }
+      return true;
     }
-    return result;
+    return false;
   }
 
-  static string fixPath( const string& fileName,
-			 const string& path ){
-    // if fileName contains pathinformation, it is replaced with path
-    // if filename contains NO pathinformation, path is always appended.
-    // of course we don't append if the path is empty
-
-    if ( !path.empty() ){
-      bool addSlash = path[path.length()] != '/';
-      string tmp;
-      string::size_type pos = fileName.rfind( '/' );
-      if ( pos == string::npos ){
-	tmp = path;
-	if ( addSlash )
-	  tmp += "/";
-	tmp += fileName;
-      }
-      else { 
-	tmp = path;
-	if ( addSlash )
-	tmp += "/";
-	tmp += fileName.substr( pos+1 );
-      }
-      return tmp;
-    }
-    else
-      return fileName;
-  }  
-
   bool CV_Experiment::Test( const string& FileName,
 			    const string& OutFile ){
     if ( !ConfirmOptions() )
@@ -174,16 +130,18 @@ namespace Timbl {
     set_verbosity( SILENT );
     if ( get_file_names( FileName ) ){
       *mylog << "Starting Cross validation test on files:" << endl;
-      for ( int i = 0; i < NumOfFiles; ++i )
-	*mylog << FileNames[i] << endl;
+      for ( const auto& name : FileNames ){
+	*mylog << name << endl;
+      }
+      size_t NumOfFiles = FileNames.size();
       TimblExperiment::Prepare( FileNames[1], false );
       TimblExperiment::Learn( FileNames[1], false );
-      for ( int filenum = 2; filenum < NumOfFiles; ++filenum )
+      for ( size_t filenum = 2; filenum < NumOfFiles; ++filenum )
 	Expand( FileNames[filenum] );
       string outName;
       string percName;
-      for ( int SkipFile = 0; SkipFile < NumOfFiles-1; ++SkipFile ) {
-	outName = fixPath( FileNames[SkipFile], outPath );
+      for ( size_t SkipFile = 0; SkipFile < NumOfFiles-1; ++SkipFile ) {
+	outName = correct_path( FileNames[SkipFile], outPath, false );
 	outName += ".cv";
 	percName = outName;
 	percName += ".%";
@@ -201,7 +159,7 @@ namespace Timbl {
 	Expand( FileNames[SkipFile] );
 	Remove( FileNames[SkipFile+1] );
       }
-      outName = fixPath( FileNames[NumOfFiles-1], outPath );
+      outName = correct_path( FileNames[NumOfFiles-1], outPath, false );
       outName += ".cv";
       percName = outName;
       percName += ".%";
@@ -210,7 +168,7 @@ namespace Timbl {
 	GetWeights( CV_WfileName, CV_fileW );
       if ( !CV_PfileName.empty() )
 	GetArrays( CV_PfileName );
-      result = TimblExperiment::Test( FileNames[NumOfFiles-1], outName ); 
+      result = TimblExperiment::Test( FileNames[NumOfFiles-1], outName );
       if ( result )
 	result = createPercFile( percName );
     }
