@@ -1,11 +1,9 @@
 /*
-  $Id: Choppers.cxx 16820 2014-01-06 10:12:30Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/Choppers.cxx $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
- 
+
   This file is part of timbl
 
   timbl is free software; you can redistribute it and/or modify
@@ -22,9 +20,9 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
 */
 #include <ostream>
 #include <iostream>
@@ -33,15 +31,15 @@
 #include <string>
 #include <cassert>
 #include "ticcutils/StringOps.h"
+#include "ticcutils/PrettyPrint.h"
 #include "timbl/Types.h"
 #include "timbl/Choppers.h"
 
 using namespace std;
-using namespace TiCC;
 
 namespace Timbl{
 
-  Chopper *Chopper::create( InputFormatType IF, bool doEx, 
+  Chopper *Chopper::create( InputFormatType IF, bool doEx,
 			    int fLen, bool doOcc ){
     Chopper *result = 0;
     switch ( IF ){
@@ -92,7 +90,7 @@ namespace Timbl{
 	result = new Tabbed_ExChopper();
       else
 	result = new Tabbed_Chopper();
-      break;      
+      break;
     case Compact:
       if ( doOcc )
 	result = new Compact_OccChopper( fLen );
@@ -108,30 +106,25 @@ namespace Timbl{
   }
 
   void Chopper::init( const string& s, size_t len, bool stripDot ) {
-    strippedInput = s;
     vSize = len+1;
     choppedInput.resize(vSize);
-    string::iterator it = strippedInput.end();
-    --it;
-    // first trim trailing spaces 
-    while ( it != strippedInput.begin() && 
-	    isspace(*it) ) --it;
-    strippedInput.erase( ++it , strippedInput.end() );
-    it = strippedInput.end();
-    --it;
+    strippedInput = s;
+    // trim spaces at end
+    strippedInput = TiCC::trim_back( strippedInput );
     if ( stripDot ){
-      // first trim trailing dot
-      if ( it != strippedInput.begin() && *it == '.' )
-	--it;
+      // now trim at most 1 trailing dot
+      auto it = strippedInput.end();
+      --it;
+      if ( *it == '.' ){
+	strippedInput.erase(it);
+      }
     }
-    // strip remaining trailing spaces
-    while ( it != strippedInput.begin() && 
-	    isspace(*it) ) --it;
-    strippedInput.erase( ++it , strippedInput.end() );
+    // trim more spaces at end
+    strippedInput = TiCC::trim_back( strippedInput );
   }
 
-  static string stripExemplarWeight( const string& Buffer,
-				     string& wght ) {
+  static string extractWeight( const string& Buffer,
+			       string& wght ) {
     string::size_type t_pos, e_pos = Buffer.length();
     // first remove trailing whitespace and dot
     e_pos = Buffer.find_last_not_of( ". \t", e_pos );
@@ -149,20 +142,20 @@ namespace Timbl{
     return string( Buffer, 0, e_pos+1 );
   }
 
-  static string stripOcc( const string& Buffer,
+  static string extractOcc( const string& Buffer,
 			  string& wght ) {
-    return stripExemplarWeight( Buffer, wght );
+    return extractWeight( Buffer, wght );
   }
 
-  size_t Chopper::countFeatures( const string& inBuffer, 
-				 InputFormatType IF,  
+  size_t Chopper::countFeatures( const string& inBuffer,
+				 InputFormatType IF,
 				 int F_length,
 				 bool chopTail ) {
     size_t result = 0;
     string buffer;
     if ( chopTail ){
       string dummy;
-      buffer = stripExemplarWeight( inBuffer, dummy );
+      buffer = extractWeight( inBuffer, dummy );
     }
     else
       buffer = inBuffer;
@@ -170,9 +163,9 @@ namespace Timbl{
     switch ( IF ){
     case ARFF:
     case C4_5:
-      for ( size_t i = 0; i < len; ++i ) {
-	if (buffer[i] == ',')
-	  result++;
+      for ( auto const& c : buffer ){
+	if ( c == ',')
+	  ++result;
       };
       break;
     case Compact:
@@ -185,40 +178,34 @@ namespace Timbl{
 	result = (len / F_length) - 1;
       break;
     case Columns:
-      for ( size_t j = 0; j < len; ++j ) {
-	if ( isspace(buffer[j]) ){
-	  result++;
-	  while ( isspace( buffer[++j] ) ){};
-	  if ( buffer[j] == '\0' )
-	    result--; // we had some trailing spaces
-	}
+      {
+	vector<string> parts;
+	size_t num = TiCC::split( buffer, parts );
+	result = num - 1;
       };
       break;
     case Tabbed:
-      for ( size_t j = 0; j < len; ++j ) {
-	if ( buffer[j] == '\t' ){
-	  result++;
-	  while ( buffer[++j]  == '\t' ){};
-	  if ( buffer[j] == '\0' )
-	    result--; // we had some trailing spaces
-	}
+      {
+	vector<string> parts;
+	size_t num = TiCC::split_at( buffer, parts, "\t" );
+	result = num - 1;
       };
-      break;      
+      break;
     default:
       throw logic_error( "CountFeatures: Illegal value in switch:" +
-			 toString(IF) );
+			 TiCC::toString(IF) );
     };
     return result;
   }
-  
- 
+
+
   InputFormatType Chopper::getInputFormat( const string& inBuffer,
 					   bool stripTail ) {
     InputFormatType IF = UnknownInputFormat;
     string buffer;
     if ( stripTail ){
       string dummy;
-      buffer = stripExemplarWeight( inBuffer, dummy );
+      buffer = extractWeight( inBuffer, dummy );
     }
     else
       buffer = inBuffer;
@@ -251,37 +238,32 @@ namespace Timbl{
     strippedInput = s;
     vSize = len+1;
     choppedInput.resize(vSize);
-    string::iterator it = strippedInput.end();
-    --it;
-    // first trim trailing spaces 
-    while ( it != strippedInput.begin() && 
-	    isspace(*it) ) --it;
-    strippedInput.erase( ++it , strippedInput.end() );
+    // trim trailing spaces
+    strippedInput = TiCC::trim_back( strippedInput );
     string wght;
-    strippedInput = stripExemplarWeight( strippedInput, wght );
+    strippedInput = extractWeight( strippedInput, wght );
     if ( wght.empty() ){
       throw logic_error( "Missing sample weight" );
     }
     else {
       double tmp;
-      if ( !stringTo<double>( wght, tmp ) ){
+      if ( !TiCC::stringTo<double>( wght, tmp ) ){
 	throw runtime_error( "Wrong sample weight: '" + wght + "'" );
       }
       else {
 	exW = tmp;
       }
     }
-    it = strippedInput.end();
-    --it;
     if ( stripDot ){
-      // first trim trailing dot
-      if ( it != strippedInput.begin() && *it == '.' )
-	--it;
+      // now trim at most 1 trailing dot
+      auto it = strippedInput.end();
+      --it;
+      if ( *it == '.' ){
+	strippedInput.erase(it);
+      }
     }
-    // strip remaining trailing spaces
-    while ( it != strippedInput.begin() && 
-	    isspace(*it) ) --it;
-    strippedInput.erase( ++it , strippedInput.end() );
+    // trim more trailing spaces
+    strippedInput = TiCC::trim_back( strippedInput );
   }
 
   void OccChopper::init( const string& s, size_t len, bool stripDot ) {
@@ -289,37 +271,33 @@ namespace Timbl{
     strippedInput = s;
     vSize = len+1;
     choppedInput.resize(vSize);
-    string::iterator it = strippedInput.end();
-    --it;
-    // first trim trailing spaces 
-    while ( it != strippedInput.begin() && 
-	    isspace(*it) ) --it;
-    strippedInput.erase( ++it , strippedInput.end() );
+    // first trim trailing spaces
+    strippedInput = TiCC::trim_back( strippedInput );
     string occS;
-    strippedInput = stripOcc( strippedInput, occS );
+    // get occ
+    strippedInput = extractOcc( strippedInput, occS );
     if ( occS.empty() ){
       throw logic_error( "Missing occurence" );
     }
     else {
       int tmp;
-      if ( !stringTo<int>( occS, tmp ) ){
+      if ( !TiCC::stringTo<int>( occS, tmp ) ){
 	throw runtime_error( "Wrong (non-integer) occurence value: '" + occS + "'" );
       }
       else {
 	occ = tmp;
       }
     }
-    it = strippedInput.end();
-    --it;
     if ( stripDot ){
-      // first trim trailing dot
-      if ( it != strippedInput.begin() && *it == '.' )
-	--it;
+      // now trim at most 1 trailing dot
+      auto it = strippedInput.end();
+      --it;
+      if ( *it == '.' ){
+	strippedInput.erase(it);
+      }
     }
     // strip remaining trailing spaces
-    while ( it != strippedInput.begin() && 
-	    isspace(*it) ) --it;
-    strippedInput.erase( ++it , strippedInput.end() );
+    strippedInput = TiCC::trim_back( strippedInput );
   }
 
   bool C45_Chopper::chop( const string& InBuf, size_t len ){
@@ -335,8 +313,8 @@ namespace Timbl{
     }
     return true;
   }
-  
-  string C45_Chopper::getString() const{ 
+
+  string C45_Chopper::getString() const{
     string res;
     for ( size_t i = 0; i < vSize; ++i ) {
       res += CodeToStr( choppedInput[i] ) + ",";
@@ -351,7 +329,7 @@ namespace Timbl{
     // WhiteSpace is skipped!
     return C45_Chopper::chop( InBuf, len );
   }
-  
+
   bool Bin_Chopper::chop( const string& InBuf, size_t len ) {
     // Lines look like this:
     // 12, 25, 333, bla.
@@ -359,32 +337,33 @@ namespace Timbl{
     init( InBuf, len, true );
     for ( size_t m = 0; m < vSize-1; ++m )
       choppedInput[m] = "0";
-    string::size_type s_pos = 0;
-    string::size_type e_pos = strippedInput.find( ',' );
-    while ( e_pos != string::npos ){
-      string tmp = string( strippedInput, s_pos, e_pos - s_pos );
+    vector<string> parts;
+    TiCC::split_at( strippedInput, parts, ",", true );
+    for ( auto const& p : parts ){
+      if ( &p == &parts.back() ){
+	choppedInput[vSize-1] = p;
+	break;
+      }
       size_t k;
-      if ( !stringTo<size_t>( tmp, k, 1, vSize-1 ) )
+      if ( !TiCC::stringTo<size_t>( p, k, 1, vSize ) ){
 	return false;
+      }
       else
 	choppedInput[k-1] = "1";
-      s_pos = e_pos + 1;
-      e_pos = strippedInput.find( ',', s_pos );
     }
-    choppedInput[vSize-1] = string( strippedInput, s_pos );
     return true;
   }
-  
-  string Bin_Chopper::getString() const { 
+
+  string Bin_Chopper::getString() const {
     string res;
     for ( size_t i = 0; i < vSize-1; ++i ) {
       if ( choppedInput[i][0] == '1' )
-	res += toString(i+1) + ",";
+	res += TiCC::toString(i+1) + ",";
     }
     res += choppedInput[vSize-1] + ",";
     return res;
   }
-  
+
   bool Compact_Chopper::chop( const string& InBuf, size_t leng ){
     init( InBuf, leng, false );
     size_t i;
@@ -398,7 +377,7 @@ namespace Timbl{
       return false;
     }
     for ( i = 0; i < vSize; ++i ) {
-      size_t index = i * fLen; 
+      size_t index = i * fLen;
       // Scan the value.
       //
       choppedInput[i] = "";
@@ -408,7 +387,7 @@ namespace Timbl{
     }
     return ( i == vSize ); // Enough?
   }
-  
+
   string Compact_Chopper::getString() const {
     string res;
     for ( size_t i = 0; i < vSize; ++i ) {
@@ -416,67 +395,53 @@ namespace Timbl{
     }
     return res;
   }
-  
+
   bool Columns_Chopper::chop( const string& InBuf, size_t len ){
     // Lines look like this:
     // one  two three bla
     init( InBuf, len, false );
-    unsigned int i = 0;
-    string::size_type s_pos = 0;
-    string::size_type e_pos = strippedInput.find_first_of( " \t" );
-    while ( e_pos != s_pos && e_pos != string::npos && i < vSize ){
-      // stop if a zero length string is found or if too many entries show up
-      choppedInput[i++] = string( strippedInput, s_pos, e_pos - s_pos );
-      s_pos = strippedInput.find_first_not_of( " \t", e_pos );
-      e_pos = strippedInput.find_first_of( " \t", s_pos );
-    }
-    if ( e_pos != string::npos )
+    vector<string> splits;
+    size_t res = TiCC::split( strippedInput, splits );
+    if ( res != vSize )
       return false;
-    if ( s_pos != string::npos && i < vSize ){
-      choppedInput[i++] = string( strippedInput, s_pos );
+    for ( size_t i=0; i < res ; ++i ){
+      choppedInput[i] = StrToCode( splits[i] );
     }
-    return ( i == vSize ); // Enough?
+    return ( res == vSize ); // Enough?
   }
-  
-  string Columns_Chopper::getString() const { 
+
+  string Columns_Chopper::getString() const {
     string res;
     for ( size_t i = 0; i < vSize; ++i ) {
       res += choppedInput[i] + " ";
     }
     return res;
   }
-  
 
-  
+
+
   bool Tabbed_Chopper::chop( const string& InBuf, size_t len ){
     // Lines look like this:
     // one  two three bla
     init( InBuf, len, false );
-    unsigned int i = 0;
-    string::size_type s_pos = 0;
-    string::size_type e_pos = strippedInput.find_first_of( "\t" );
-    while ( e_pos != s_pos && e_pos != string::npos && i < vSize ){
-      // stop if a zero length string is found or if too many entries show up
-      choppedInput[i++] = StrToCode( string( strippedInput, s_pos, e_pos - s_pos ) );
-      s_pos = strippedInput.find_first_not_of( "\t", e_pos );
-      e_pos = strippedInput.find_first_of( "\t", s_pos );
-    }
-    if ( e_pos != string::npos )
+    vector<string> splits;
+    size_t res = TiCC::split_at( strippedInput, splits, "\t" );
+    if ( res != vSize )
       return false;
-    if ( s_pos != string::npos && i < vSize ){
-      choppedInput[i++] = StrToCode( string( strippedInput, s_pos ) );
+    for ( size_t i=0; i < res ; ++i ){
+      choppedInput[i] = StrToCode( splits[i] );
     }
-    return ( i == vSize ); // Enough?
+    return ( res == vSize ); // Enough?
   }
-  
-  string Tabbed_Chopper::getString() const { 
+
+  string Tabbed_Chopper::getString() const {
     string res;
     for ( size_t i = 0; i < vSize; ++i ) {
       res += CodeToStr( choppedInput[i] ) + "\t";
     }
     return res;
   }
-  
+
   bool Sparse_Chopper::chop( const string& InBuf, size_t len ){
     // Lines look like this:
     // (12,value1) (25,value2) (333,value3) bla.
@@ -485,45 +450,46 @@ namespace Timbl{
     for ( size_t m = 0; m < vSize-1; ++m )
       choppedInput[m] = DefaultSparseString;
     choppedInput[vSize-1] = "";
-    string::size_type s_pos = strippedInput.find( "(" );
-    if ( s_pos == string::npos )
-      choppedInput[vSize-1] = TiCC::trim(strippedInput);
-    else {
-      string::size_type m_pos, e_pos = strippedInput.find( ")" );
-      while ( s_pos < e_pos &&
-	      s_pos != string::npos  && e_pos != string::npos ){
-	m_pos = strippedInput.find( ',', s_pos );
-	string temp = string( strippedInput, s_pos + 1, m_pos - s_pos - 1 );
-	size_t k = 0;
-	if ( !stringTo<size_t>( temp, k, 1, vSize-1 ) )
-	  return false;
-	else {
-	  choppedInput[k-1] = string( strippedInput, m_pos + 1, e_pos - m_pos -1 );
-	  choppedInput[k-1] = StrToCode( choppedInput[k-1] );
+    vector<string> entries;
+    size_t num_ent = TiCC::split_at_first_of( strippedInput, entries, "()" );
+    if ( num_ent < 1 )
+      return false;
+    for ( const auto& ent : entries ){
+      --num_ent;
+      vector<string> parts;
+      size_t num = TiCC::split_at( ent, parts, "," );
+      if ( num != 2 ){
+	if ( num == 1 && num_ent == 0 ){
+	  // the target has no ','
+	  choppedInput[vSize-1] = TiCC::trim(parts[0]);
+	  return !choppedInput[vSize-1].empty();
 	}
-	s_pos = strippedInput.find( '(', e_pos );
-	if ( s_pos == string::npos ){
-	  e_pos = strippedInput.find_first_not_of( ") \t", e_pos );
-	  if ( e_pos != string::npos ){
-	    choppedInput[vSize-1] = string( strippedInput, e_pos );
-	    choppedInput[vSize-1] = TiCC::trim( choppedInput[vSize-1] );
-	  }
-	}
-	else
-	  e_pos = strippedInput.find( ')', s_pos );
+	return false;
       }
+      if ( num_ent == 0 ){
+	// missing a target!
+	return false;
+      }
+      size_t index;
+      if ( !TiCC::stringTo( parts[0], index ) ){
+	return false;
+      }
+      if ( index < 1 || index >= vSize ){
+	return false;
+      }
+      choppedInput[index-1] = StrToCode( parts[1] );
     }
-    return !choppedInput[vSize-1].empty();
+    return true;
   }
-  
+
   string Sparse_Chopper::getString() const {
     string res;
     for ( size_t i = 0; i < vSize-1; ++i ) {
       if ( choppedInput[i] != DefaultSparseString )
-	res += "(" + toString( i+1 ) + "," + CodeToStr(choppedInput[i]) + ")";
+	res += "(" + TiCC::toString( i+1 ) + "," + CodeToStr(choppedInput[i]) + ")";
     }
     res += choppedInput[vSize-1] + ",";
     return res;
-  }  
-  
+  }
+
 }
