@@ -1,11 +1,9 @@
 /*
-  $Id: Common.cxx 16820 2014-01-06 10:12:30Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/Common.cxx $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
- 
+
   This file is part of timbl
 
   timbl is free software; you can redistribute it and/or modify
@@ -22,9 +20,9 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
 */
 #include <sstream>
 #include <cstdlib>
@@ -44,7 +42,7 @@ namespace Common {
   }
   string Version() { return VERSION; }
   string VersionName() { return PACKAGE_STRING; }
-  string BuildInfo() { 
+  string BuildInfo() {
     return Version() + ", compiled on " + __DATE__ + ", " +  __TIME__;
   }
 
