@@ -1,9 +1,7 @@
 /*
-  $Id: GetOptClass.cxx 17567 2014-08-26 12:13:53Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/GetOptClass.cxx $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
 
   This file is part of timbl
@@ -22,9 +20,9 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
 */
 #include <string>
 #include <fstream>
@@ -37,14 +35,13 @@
 #include "timbl/Common.h"
 #include "timbl/Types.h"
 #include "timbl/Options.h"
-#include "timbl/Instance.h"
+#include "timbl/MsgClass.h"
 #include "timbl/Metrics.h"
-#include "timbl/CommandLine.h"
+#include "ticcutils/CommandLine.h"
 #include "timbl/GetOptClass.h"
 #include "timbl/TimblExperiment.h"
 
 using namespace std;
-using namespace TiCC;
 
 namespace Timbl {
 
@@ -88,14 +85,14 @@ namespace Timbl {
     }
     target_pos = -1;
     metricsArray.resize(MaxFeats+1);
-    for ( int i=0; i < MaxFeats+1; ++i ){
-      metricsArray[i] = UnknownMetric;
+    for ( auto& m : metricsArray ){
+      m = UnknownMetric;
     }
     outPath = "";
     occIn = 0;
   }
 
-  GetOptClass::GetOptClass( CL_Options& Opts ):
+  GetOptClass::GetOptClass( const TiCC::CL_Options& opts ):
     LocalInputFormat( UnknownInputFormat ),
     MaxFeats(-1),
     target_pos(-1),
@@ -108,11 +105,10 @@ namespace Timbl {
     N_present( false ),
     parent_socket_os( 0 ) {
     int MaxF = DEFAULT_MAX_FEATS;
-    bool the_mood;
     string optie;
-    if ( Opts.Find( 'N', optie, the_mood ) ){
+    if ( opts.is_present( 'N', optie ) ){
       N_present = true;
-      MaxF = stringTo<int>( optie );
+      MaxF = TiCC::stringTo<int>( optie );
     }
     set_default_options( MaxF );
   }
@@ -207,12 +203,12 @@ namespace Timbl {
 	  }
 	}
 	if ( LocalInputFormat != UnknownInputFormat ){
-	  optline = "INPUTFORMAT: " + toString(LocalInputFormat);
+	  optline = "INPUTFORMAT: " + TiCC::toString(LocalInputFormat);
 	  if (!Exp->SetOption( optline ))
 	    return false;
 	}
 	if ( target_pos != -1 ){
-	  optline = "TARGET_POS: " + toString<int>(target_pos-1);
+	  optline = "TARGET_POS: " + TiCC::toString<int>(target_pos-1);
 	  if (!Exp->SetOption( optline ))
 	    return false;
 	}
@@ -243,26 +239,26 @@ namespace Timbl {
 	    return false;
 	}
 	if ( f_length > 0 ){
-	  optline = "FLENGTH: " + toString<int>(f_length);
+	  optline = "FLENGTH: " + TiCC::toString<int>(f_length);
 	  if (!Exp->SetOption( optline ))
 	    return false;
 	}
 	if ( local_weight != Unknown_w ){
-	  optline = "WEIGHTING: " + toString(local_weight);
+	  optline = "WEIGHTING: " + TiCC::toString(local_weight);
 	  Exp->SetOption( optline );
 	}
 	if ( do_all_weights ){
 	  optline = "ALL_WEIGHTS: true";
 	  Exp->SetOption( optline );
 	}
-	optline = "MAXBESTS: " + toString<int>(maxbests);
+	optline = "MAXBESTS: " + TiCC::toString<int>(maxbests);
 	Exp->SetOption( optline );
 	if ( BinSize > 0 ){
-	  optline = "BIN_SIZE: " + toString<int>(BinSize);
+	  optline = "BIN_SIZE: " + TiCC::toString<int>(BinSize);
 	  Exp->SetOption( optline );
 	}
 	if ( BeamSize > 0 ){
-	  optline = "BEAM_SIZE: " + toString<int>(BeamSize);
+	  optline = "BEAM_SIZE: " + TiCC::toString<int>(BeamSize);
 	  Exp->SetOption( optline );
 	}
 	if ( local_algo == TRIBL_a && threshold < 0 ){
@@ -278,15 +274,15 @@ namespace Timbl {
 	    Error( "invalid -q option. Must be > 0 " );
 	    return false;
 	  }
-	  optline = "TRIBL_OFFSET: " + toString<int>(threshold);
+	  optline = "TRIBL_OFFSET: " + TiCC::toString<int>(threshold);
 	  Exp->SetOption( optline );
 	}
 	if ( igThreshold > 0 ){
-	  optline = "IG_THRESHOLD: " + toString<int>(igThreshold);
+	  optline = "IG_THRESHOLD: " + TiCC::toString<int>(igThreshold);
 	  Exp->SetOption( optline );
 	}
 	if ( local_order != UnknownOrdening ){
-	  optline = "TREE_ORDER: " + toString(local_order);
+	  optline = "TREE_ORDER: " + TiCC::toString(local_order);
 	  Exp->SetOption( optline );
 	}
 	if ( !outPath.empty() ){
@@ -345,7 +341,7 @@ namespace Timbl {
 	return false;
       }
       if ( occIn > 0 ){
-	Exp->SetOption( "HANDLE_OCCURRENCES: " + toString(occIn) );
+	Exp->SetOption( "HANDLE_OCCURRENCES: " + TiCC::toString(occIn) );
       }
       else if ( do_sample_weights ){
 	Exp->SetOption(  "EXEMPLAR_WEIGHTS: true" );
@@ -363,47 +359,47 @@ namespace Timbl {
       if ( local_metric == UnknownMetric ){
 	// Ok, so NO defaults at all (API usage for instance)
 	local_metric = Overlap;
-	for ( size_t j=0; j < metricsArray.size(); ++j ){
-	  metricsArray[j] = Overlap;
+	for ( auto& m : metricsArray ){
+	  m = Overlap;
 	}
 
       }
-      optline = "GLOBAL_METRIC: " + toString(local_metric);
+      optline = "GLOBAL_METRIC: " + TiCC::toString(local_metric);
       Exp->SetOption( optline );
       if ( bootstrap_lines > 0 ){
-	optline = "IB2_OFFSET: " + toString<int>(bootstrap_lines);
+	optline = "IB2_OFFSET: " + TiCC::toString<int>(bootstrap_lines);
 	Exp->SetOption( optline );
       }
       if ( local_normalisation != unknownNorm ){
-	optline = "NORMALISATION: " + toString<normType>( local_normalisation );
+	optline = "NORMALISATION: " + TiCC::toString<normType>( local_normalisation );
 	Exp->SetOption( optline );
 	if ( local_normalisation == addFactorNorm ){
-	  optline = "NORM_FACTOR: " + toString<double>( local_norm_factor );
+	  optline = "NORM_FACTOR: " + TiCC::toString<double>( local_norm_factor );
 	  Exp->SetOption( optline );
 	}
       }
-      optline = "MVD_LIMIT: " + toString<int>(mvd_limit);
+      optline = "MVD_LIMIT: " + TiCC::toString<int>(mvd_limit);
       Exp->SetOption( optline );
-      optline = "NEIGHBORS: " + toString<int>(no_neigh);
+      optline = "NEIGHBORS: " + TiCC::toString<int>(no_neigh);
       if ( Exp->SetOption( optline ) ){
-	optline = "DECAY: " + toString(local_decay);
+	optline = "DECAY: " + TiCC::toString(local_decay);
 	if ( Exp->SetOption( optline ) ){
-	  optline = "DECAYPARAM_A: " + toString<double>(local_decay_alfa);
+	  optline = "DECAYPARAM_A: " + TiCC::toString<double>(local_decay_alfa);
 	  if ( Exp->SetOption( optline ) ){
-	    optline = "DECAYPARAM_B: " + toString<double>(local_decay_beta);
+	    optline = "DECAYPARAM_B: " + TiCC::toString<double>(local_decay_beta);
 	    if ( Exp->SetOption( optline ) ){
-	      optline = "CLIP_FACTOR: " + toString<int>(clip_freq);
+	      optline = "CLIP_FACTOR: " + TiCC::toString<int>(clip_freq);
 	      if ( Exp->SetOption( optline ) ){
-		optline = "SEED: " + toString<int>(seed);
+		optline = "SEED: " + TiCC::toString<int>(seed);
 		if ( Exp->SetOption( optline ) ){
-		  optline = "PROGRESS: " + toString<int>(local_progress);
+		  optline = "PROGRESS: " + TiCC::toString<int>(local_progress);
 		  if ( Exp->SetOption( optline ) ){
 		    optline = "VERBOSITY: " +
-		      toString(myVerbosity);
+		      TiCC::toString(myVerbosity);
 		    if ( Exp->SetOption( optline ) ){
 		      for ( size_t i=0; i < metricsArray.size(); ++i ){
-			optline = "METRICS: " + toString<int>( i ) + "=" +
-			  toString(metricsArray[i]);
+			optline = "METRICS: " + TiCC::toString<int>( i ) + "=" +
+			  TiCC::toString(metricsArray[i]);
 			if (!Exp->SetOption( optline ) ){
 			  Error( "changing metric is not possible at this stage" );
 			  return false;
@@ -437,7 +433,7 @@ namespace Timbl {
       while( eit != line.end() && isdigit( *eit ) ) ++eit;
       string tmp = string( it, eit );
       size_t k;
-      if ( stringTo<size_t>( tmp, k, 1, metricsArray.size() ) ){
+      if ( TiCC::stringTo<size_t>( tmp, k, 1, metricsArray.size() ) ){
 	if ( metricsArray[k] != UnknownMetric && metricsArray[k] != Value ){
 	  Error( "metric of feature " + tmp +
 		 " is multiply changed!" );
@@ -460,7 +456,7 @@ namespace Timbl {
 	eit = it;
 	while( eit != line.end() && isdigit( *eit ) ) ++eit;
 	tmp = string( it, eit );
-	m = stringTo<int>(tmp);
+	m = TiCC::stringTo<int>(tmp);
 	if ( m <= 0 || m > metricsArray.size() ){
 	  Error( "illegal value in metric description: -m " + line );
 	  return false;
@@ -478,7 +474,7 @@ namespace Timbl {
 	  for ( size_t j=k+1; j <= m && j <= metricsArray.size(); ++j ){
 	    if ( metricsArray[j] != UnknownMetric
 		 && metricsArray[j] != Value ){
-	      Error( "metric of feature " + toString<int>(j) +
+	      Error( "metric of feature " + TiCC::toString<int>(j) +
 		     " is multiply changed!" );
 	      return false;
 	    }
@@ -548,10 +544,8 @@ namespace Timbl {
 	}
 	else {
 	  // set the defaults
-	  for ( vector<MetricType>::iterator it=metricsArray.begin();
-		it != metricsArray.end();
-		++it ){
-	    *it = Def;
+	  for ( auto& mt : metricsArray ){
+	    mt = Def;
 	  }
 	  return true;
 	}
@@ -562,10 +556,8 @@ namespace Timbl {
       }
       else {
 	// deviating options expected. reset the array
-	for ( vector<MetricType>::iterator it=metricsArray.begin();
-	      it != metricsArray.end();
-	      ++it ){
-	  *it = UnknownMetric;
+	for ( auto& mt : metricsArray ){
+	  mt = UnknownMetric;
 	}
 	++p;
 	MetricType TmpMT;
@@ -608,7 +600,7 @@ namespace Timbl {
 	  }
 	  metricClass *tmpMC = getMetricClass(Def);
 	  if ( TmpMT != Ignore && tmpMC->isSimilarityMetric() ){
-	    Error( "Similarity metric " + toString( Def )
+	    Error( "Similarity metric " + TiCC::toString( Def )
 		   + " only accepts -I specifications: -m " + Mline );
 	    delete tmpMC;
 	    return false;
@@ -635,11 +627,9 @@ namespace Timbl {
 	  //
 	  // set defaults for those still unset
 	  //
-	  for ( vector<MetricType>::iterator it=metricsArray.begin();
-		it != metricsArray.end();
-		++it ){
-	    if ( *it == UnknownMetric )
-	      *it = Def;
+	  for ( auto& mt : metricsArray ){
+	    if ( mt == UnknownMetric )
+	      mt = Def;
 	  }
 	}
       }
@@ -664,92 +654,53 @@ namespace Timbl {
     return false;
   }
 
-  bool GetOptClass::parse_options( const CL_Options& opts,
+  bool GetOptClass::parse_options( const TiCC::CL_Options& opts,
 				   const int mode ){
     opt_changed = true;
     //    cerr << "options: " << opts << endl;
     //    cerr << "mode: " << mode << endl;
-    const char *q;
-    list<CL_item>::const_iterator curr_opt;
-    curr_opt = opts.Opts.begin();
-    if ( curr_opt == opts.Opts.end() ){
-      return true;
-    }
-    const char *ok_opt;
-    switch ( mode ){
-    case 0:
-      ok_opt = "a:b:B:c:C:d:De:F:G:Hk:l:L:m:M:n:N:o:O:p:q:QR:st:T:v:w:Wx";
-      break;
-    case 1:
-      // limited usage, for @t
-      ok_opt = "d:e:G:k:L:m:p:QR:v:x";
-      break;
-    case 2:
-      // limited usage, for Server
-      ok_opt = "C:d:G:k:l:L:p:Qv:x";
-      break;
-    default:
-      ok_opt = NULL;
-      string msg = string("Invalid value '") + toString(mode)
-	+ "' in switch ("
-	+ __FILE__  + "," + toString(__LINE__) + ")\n"
-	+ "ABORTING now";
-      throw std::logic_error( msg );
-    }
-    while ( curr_opt != opts.Opts.end()  ) {
+    for( auto const& curr_opt: opts ){
+      //      cerr << "process " << curr_opt << endl;
       bool mood = false;
-      bool longOpt = false;
       string long_option;
-      string myoptarg = curr_opt->Option();
-      char option = curr_opt->OptChar();
+      bool longOpt = curr_opt.isLong();
+      string opt_val = curr_opt.Option();
+      char opt_char = curr_opt.OptChar();
 
-      if ( curr_opt->isLong() ){
-	long_option = curr_opt->OptWord();
-	longOpt = true;
+      if ( longOpt ){
+	long_option = curr_opt.OptWord();
       }
       else {
-	mood = curr_opt->getMood();
+	mood = curr_opt.getMood();
       }
       //      cerr << "long option:" << long_option << endl;
-      //      cerr << "   myoptarg:" << myoptarg << endl;
-      if ( !strchr( ok_opt, option ) ){
-	// invalid option
-	switch ( mode ){
-	case 1:
-	case 2:{
-	  string LongLine;
-	  q = ok_opt;
-	  while ( *q ){
-	    if ( *q != ':'  ){
-	      LongLine = LongLine + *q + ' ';
-	    }
-	    q++;
-	  }
-	  Error( string("Illegal option, -") + (char)option
-		 + ", only the following options are allowed: "
-		 + LongLine );
-	}
-	break;
-	default:
-	  break;
-	}
-	return false;
-      };
-
+      //      cerr << "   opt_val:" << opt_val << endl;
       try {
-	//	cerr << "try " << option << endl;
-	switch (option) {
+	//	cerr << "try " << opt_char << endl;
+	switch (opt_char) {
 	case 'a':
-	  if ( !stringTo<AlgorithmType>( myoptarg, local_algo ) ){
-	    Error( "illegal -a value: " + myoptarg );
-	    return false;
+	  {
+	    AlgorithmType tmp_a = IB1_a;
+	    if ( !TiCC::stringTo<AlgorithmType>( opt_val, tmp_a ) ){
+	      Error( "illegal -a value: " + opt_val );
+	      return false;
+	    }
+	    else if ( tmp_a != IB1_a ){
+	      if ( local_algo == LOO_a || local_algo == CV_a ){
+		Error( "only IB1 algorithm is allowed for: " + TiCC::toString(local_algo)  );
+		return false;
+	      }
+	      else {
+		local_algo = tmp_a;
+	      }
+	    }
 	  }
 	  break;
 
 	case 'b':
-	  bootstrap_lines = stringTo<int>( myoptarg );
+	  bootstrap_lines = TiCC::stringTo<int>( opt_val );
 	  if ( bootstrap_lines < 1 ){
-	    Error( "illegal value for -b option: " + myoptarg );
+	    Error( "illegal value for -b option: " + opt_val );
 	    return false;
 	  }
 	  break;
@@ -757,408 +708,388 @@ namespace Timbl {
 	case 'B':
 	  if ( longOpt ){
 	    if ( long_option == "Beam" ){
-	      if ( !stringTo<int>( myoptarg, BeamSize )
+	      if ( !TiCC::stringTo<int>( opt_val, BeamSize )
 		   || BeamSize <= 0 ){
-		Error( "illegal value for -Beam option: " + myoptarg );
+		Error( "illegal value for --Beam option: " + opt_val );
 		return false;
 	      }
 	    }
-	    else {
-	      Error( "invalid option: Did you mean '--Beam'?" );
-	      return false;
-	    }
 	  }
-	  else if ( myoptarg.find("eam") != string::npos ){
-	    Error( "invalid option: Did you mean '--B" + myoptarg + "'?" );
+	  else if ( opt_val.find("eam") != string::npos ){
+	    Error( "invalid option: Did you mean '--B" + opt_val + "'?" );
 	    return false;
 	  }
 	  else {
-	    BinSize = stringTo<int>( myoptarg );
+	    BinSize = TiCC::stringTo<int>( opt_val );
 	    if ( BinSize <= 1 ){
-	      Error( "illegal value for -B option: " + myoptarg );
+	      Error( "illegal value for -B option: " + opt_val );
 	      return false;
 	    }
 	  }
 	  break;
 
-      case 'c':
-	if ( longOpt ){
-	  if ( long_option == "clones" ){
-	    clones = stringTo<int>( myoptarg );
-	    if ( clones <= 0 ){
-	      Error( "invalid value for " + long_option + ": '"
-		     + myoptarg + "'" );
-	      return false;
-	    }
-	  }
-	}
-	else {
-	  clip_freq = stringTo<int>( myoptarg );
-	  if ( clip_freq < 0 ){
-	    Error( "illegal value for -c option: " + myoptarg );
-	    return false;
-	  }
-	}
-	break;
-
-	case 'd': {
-	  string::size_type pos1 = myoptarg.find( ":" );
-	  if ( pos1 == string::npos ){
-	    pos1 = myoptarg.find_first_of( "0123456789" );
-	    if ( pos1 != string::npos ){
-	      if ( ! ( stringTo<DecayType>( string( myoptarg, 0, pos1 ),
-					    local_decay ) &&
-		       stringTo<double>( string( myoptarg, pos1 ),
-					 local_decay_alfa ) ) ){
-		Error( "illegal value for -d option: " + myoptarg );
+	case 'c':
+	  if ( longOpt ){
+	    if ( long_option == "clones" ){
+	      if ( !TiCC::stringTo<int>( opt_val, clones )
+		   || clones <= 0 ){
+		Error( "invalid value for --clones option: '"
+		       + opt_val + "'" );
 		return false;
 	      }
 	    }
-	    else if ( !stringTo<DecayType>( myoptarg, local_decay ) ){
-	      Error( "illegal value for -d option: " + myoptarg );
+	  }
+	  else {
+	    if ( !TiCC::stringTo<int>( opt_val, clip_freq )
+		 || clip_freq < 0 ){
+	      Error( "illegal value for -c option: " + opt_val );
+	      return false;
+	    }
+	  }
+	  break;
+
+	case 'd': {
+	  string::size_type pos1 = opt_val.find( ":" );
+	  if ( pos1 == string::npos ){
+	    pos1 = opt_val.find_first_of( "0123456789" );
+	    if ( pos1 != string::npos ){
+	      if ( ! ( TiCC::stringTo<DecayType>( string( opt_val, 0, pos1 ),
+					    local_decay ) &&
+		       TiCC::stringTo<double>( string( opt_val, pos1 ),
+					 local_decay_alfa ) ) ){
+		Error( "illegal value for -d option: " + opt_val );
+		return false;
+	      }
+	    }
+	    else if ( !TiCC::stringTo<DecayType>( opt_val, local_decay ) ){
+	      Error( "illegal value for -d option: " + opt_val );
 	      return false;
 	    }
 	  }
 	  else {
-	    string::size_type pos2 = myoptarg.find( ':', pos1+1 );
+	    string::size_type pos2 = opt_val.find( ':', pos1+1 );
 	    if ( pos2 == string::npos ){
-	      pos2 = myoptarg.find_first_of( "0123456789", pos1+1 );
+	      pos2 = opt_val.find_first_of( "0123456789", pos1+1 );
 	      if ( pos2 != string::npos ){
-		if ( ! ( stringTo<DecayType>( string( myoptarg, 0, pos1 ),
+		if ( ! ( TiCC::stringTo<DecayType>( string( opt_val, 0, pos1 ),
 					      local_decay ) &&
-			 stringTo<double>( string( myoptarg, pos2 ),
+			 TiCC::stringTo<double>( string( opt_val, pos2 ),
 					   local_decay_alfa ) ) ){
-		  Error( "illegal value for -d option: " + myoptarg );
+		  Error( "illegal value for -d option: " + opt_val );
 		  return false;
 		}
 	      }
 	      else {
-		Error( "illegal value for -d option: " + myoptarg );
+		Error( "illegal value for -d option: " + opt_val );
 		return false;
 	      }
 	    }
 	    else {
-	      if ( ! ( stringTo<DecayType>( string( myoptarg, 0, pos1 ),
+	      if ( ! ( TiCC::stringTo<DecayType>( string( opt_val, 0, pos1 ),
 					    local_decay ) &&
-		       stringTo<double>( string( myoptarg, pos1+1, pos2-pos1-1 ),
+		       TiCC::stringTo<double>( string( opt_val, pos1+1, pos2-pos1-1 ),
 					 local_decay_alfa ) &&
-		       stringTo<double>( string( myoptarg, pos2+1 ),
+		       TiCC::stringTo<double>( string( opt_val, pos2+1 ),
 					 local_decay_beta ) ) ){
-		Error( "illegal value for -d option: " + myoptarg );
+		Error( "illegal value for -d option: " + opt_val );
 		return false;
 	      }
 	    }
 	  }
-	break;
-      }
+	  break;
+	}
 
-      case 'D':
-	if ( longOpt ){
-	  if ( long_option == "Diversify" )
-	    do_diversify = true;
+	case 'D':
+	  if ( longOpt ){
+	    if ( long_option == "Diversify" )
+	      do_diversify = true;
+	    else {
+	      Error( "invalid option: Did you mean '--Diversify' ?" );
+	      return false;
+	    }
+	  }
 	  else {
-	    Error( "invalid option: Did you mean '--Diversify' ?" );
+	    keep_distributions = mood;
+	  }
+	  break;
+
+	case 'e':
+	  if ( !TiCC::stringTo<int>( opt_val, estimate )
+	       || estimate < 0 ){
+	    Error( "illegal value for -e option: " + opt_val );
 	    return false;
 	  }
-	}
-	else if ( myoptarg.size() > 1 ){
-	  Error( "invalid option: Did you mean '--Diversify'?" );
-	  return false;
-	}
-	else
-	  keep_distributions = mood;
-	break;
+	  break;
 
-      case 'e':
-	estimate = stringTo<int>( myoptarg );
-	if ( estimate < 0 ){
-	  Error( "illegal value for -e option: " + myoptarg );
-	  return false;
-	}
-	break;
+	case 'F':
+	  if ( !TiCC::stringTo<InputFormatType>( opt_val, LocalInputFormat ) ){
+	    Error( "illegal value for -F option: " + opt_val );
+	    return false;
+	  }
+	  break;
 
-      case 'F':
-	if ( !stringTo<InputFormatType>( myoptarg, LocalInputFormat ) ){
-	  Error( "illegal value for -F option: " + myoptarg );
-	  return false;
-	}
-	break;
+	case 'G':
+	  if ( opt_val.empty() )
+	    local_normalisation = probabilityNorm;
+	  else {
+	    string::size_type pos1 = opt_val.find( ":" );
+	    if ( pos1 == string::npos ){
+	      local_normalisation = TiCC::stringTo<normType>( opt_val );
+	      local_norm_factor = 1;
+	    }
+	    else {
+	      local_normalisation = TiCC::stringTo<normType>( string( opt_val, 0, pos1 ) );
+	      if ( !TiCC::stringTo<double>( string( opt_val, pos1+1 ),
+				      local_norm_factor ) ||
+		   local_norm_factor < Epsilon ){
+		Error( "illegal value for -G option: " + opt_val );
+		return false;
+	      }
+	    }
+	    if ( local_normalisation == unknownNorm ){
+	      Error( "illegal value for -G option: " + opt_val );
+	      return false;
+	    }
+	  }
+	  break;
 
-      case 'G':
-	if ( myoptarg.empty() )
-	  local_normalisation = probabilityNorm;
-	else {
-	  string::size_type pos1 = myoptarg.find( ":" );
+	case 'H':
+	  do_hashed = mood;
+	  break;
+
+	case 'k':
+	  if ( !TiCC::stringTo<int>( opt_val, no_neigh )
+	       || no_neigh <= 0 ){
+	    Error( "illegal value for -k option: " + opt_val );
+	    return false;
+	  }
+	  break;
+
+	case 'l':
+	  if ( !TiCC::stringTo<int>( opt_val, f_length )
+	       || f_length <= 0 ){
+	    Error( "illegal value for -l option: " + opt_val );
+	    return false;
+	  }
+	  break;
+
+	case 'L': {
+	  string::size_type pos1 = opt_val.find( ":" );
 	  if ( pos1 == string::npos ){
-	    local_normalisation = stringTo<normType>( myoptarg );
-	    local_norm_factor = 1;
-	  }
-	  else {
-	    local_normalisation = stringTo<normType>( string( myoptarg, 0, pos1 ) );
-	    if ( !stringTo<double>( string( myoptarg, pos1+1 ),
-				    local_norm_factor ) ||
-		 local_norm_factor < Epsilon ){
-	      Error( "illegal value for -G option: " + myoptarg );
-	      return false;
-	    }
-	  }
-	  if ( local_normalisation == unknownNorm ){
-	    Error( "illegal value for -G option: " + myoptarg );
-	    return false;
-	  }
-	}
-	break;
-
-      case 'H':
-	do_hashed = mood;
-	break;
-
-      case 'k':
-	no_neigh = stringTo<int>(myoptarg);
-	if ( no_neigh <= 0 ){
-	  Error( "illegal value for -k option: " + myoptarg );
-	  return false;
-	}
-	break;
-
-      case 'l':
-	f_length = stringTo<int>( myoptarg );
-	if ( f_length <= 0 ){
-	  Error( "illegal value for -l option: " + myoptarg );
-	  return false;
-	}
-	break;
-
-      case 'L': {
-	string::size_type pos1 = myoptarg.find( ":" );
-	if ( pos1 == string::npos ){
-	  pos1 = myoptarg.find_first_of( "0123456789" );
-	  if ( pos1 != string::npos ){
-	    mvd_limit = stringTo<int>( myoptarg );
-	    if ( mvd_limit <= 0 ){
-	      Error( "illegal value for -L option: " + myoptarg );
-	      return false;
-	    }
-	  }
-	}
-	else {
-	  mvd_limit = stringTo<int>( string( myoptarg, pos1+1 ) );
-	  if ( mvd_limit <= 0 ){
-	    Error( "illegal value for -L option: " + myoptarg );
-	    return false;
-	  }
-	}
-	break;
-      }
-      case 'm':
-	if ( !parse_metrics( myoptarg, local_metric ) )
-	  return false;
-	break;
-
-      case 'M':
-	maxbests = stringTo<int>( myoptarg );
-	if ( maxbests <= 0 ){
-	  Error( "illegal value for -M option: " + myoptarg );
-	  return false;
-	}
-	break;
-
-      case 'N':
-	// skip previously parsed NumOfFeatures info.
-	break;
-
-      case 'O':
-	outPath = myoptarg;
-	break;
-
-      case 'o':
-	if ( longOpt ){
-	  if ( long_option == "occurrences" ){
-	    if ( myoptarg.empty() ){
-	      Error( "missing value for '--occurrences'" );
-	      return false;
-	    }
-	    if ( myoptarg == "train" )
-	      occIn = 1;
-	    else if ( myoptarg == "test" )
-	      occIn = 2;
-	    else if ( myoptarg == "both" )
-	      occIn = 3;
-	    else {
-	      Error( "invalid --ocurrences value." );
-	      return false;
-	    }
-	  }
-	  else {
-	    Error( "invalid option: Did you mean '--ocurrences' ?" );
-	    return false;
-	  }
-	}
-	else if ( myoptarg.find("ccurences") != string::npos ){
-	  Error( "invalid option: Did you mean '--occurrences' ?" );
-	  return false;
-	}
-	break;
-
-      case 'p':
-	local_progress = stringTo<int>( myoptarg );
-	break;
-
-      case 'q':
-	threshold = stringTo<int>( myoptarg );
-	break;
-
-      case 'Q':
-	do_query = true;
-	break;
-
-      case 'R':
-	if ( isdigit(myoptarg[0]) )
-	  seed = stringTo<int>( myoptarg );
-	else {
-	  Error( "Integer argument for Random Seed expected (-R option)" );
-	  return false;
-	}
-	break;
-
-      case 's':
-	if ( longOpt ){
-	  if ( long_option == "sloppy" ){
-	    bool val;
-	    if ( !isBoolOrEmpty(myoptarg,val) ){
-	      Error( "invalid value for sloppy: '"
-		     + myoptarg + "'" );
-	      return false;
-	    }
-	    do_sloppy_loo = val;
-	  }
-	  else if ( long_option == "silly" ){
-	    bool val;
-	    if ( !isBoolOrEmpty(myoptarg,val) ){
-	      Error( "invalid value for silly: '"
-		     + myoptarg + "'" );
-	      return false;
-	    }
-	    do_silly = val;
-	  }
-	  else {
-	    Error( "invalid option: Did you mean '--sloppy or --silly' ?" );
-	    return false;
-	  }
-	}
-	else {
-	  if ( myoptarg.empty() ){
-	    do_sample_weights = true;
-	  }
-	  else {
-	    if ( isdigit(myoptarg[0]) ){
-	      int val = stringTo<int>( myoptarg );
-	      if ( val == 0 ){
-		do_ignore_samples = true;
-		do_ignore_samples_test = false;
-		do_sample_weights = true;
-	      }
-	      else if ( val == 1 ){
-		do_ignore_samples_test = true;
-		do_sample_weights = true;
+	    pos1 = opt_val.find_first_of( "0123456789" );
+	    if ( pos1 != string::npos ){
+	      if ( !TiCC::stringTo<int>( opt_val, mvd_limit )
+		   || mvd_limit <= 0 ){
+		Error( "illegal value for -L option: " + opt_val );
+		return false;
 	      }
 	    }
-	    if ( !do_sample_weights) {
-	      Error( "invalid value for -s: '" + myoptarg + "' (maybe you meant --s" + myoptarg + " ?)" );
-	      return false;
-	    }
-	  }
-	}
-	break;
-
-      case 't':
-	if ( compare_nocase( myoptarg, "leave_one_out" ) )
-	  local_algo = LOO_a;
-	else if ( compare_nocase( myoptarg, "cross_validate" ) )
-	  local_algo = CV_a;
-	break;
-
-      case 'T': {
-	if ( longOpt ){
-	  if ( long_option == "Threshold" ){
-	    if ( !stringTo<int>(myoptarg, igThreshold )
-		 || igThreshold < 0 ){
-	      Error( "invalid value for Threshold: " + myoptarg );
-	      return false;
-	    }
-	  }
-	  else if ( long_option == "Treeorder" ){
-	    if ( !stringTo<OrdeningType>( myoptarg, local_order ) ){
-	      Error( "invalid value for Treeorder: " + myoptarg );
-	      return false;
-	    }
 	  }
 	  else {
-	    Error( "invalid option: Did you mean '--Threshold' or --Treeorder ?" );
+	    if ( !TiCC::stringTo<int>( string( opt_val, pos1+1 ), mvd_limit )
+		 || mvd_limit <= 0 ){
+	      Error( "illegal value for -L option: " + opt_val );
+	      return false;
+	    }
+	  }
+	  break;
+	}
+	case 'm':
+	  if ( !parse_metrics( opt_val, local_metric ) )
+	    return false;
+	  break;
+
+	case 'M':
+	  if ( !TiCC::stringTo<int>( opt_val, maxbests )
+	       || maxbests <= 0 ){
+	    Error( "illegal value for -M option: " + opt_val );
+	    return false;
+	  }
+	  break;
+
+	case 'N':
+	  // skip previously parsed NumOfFeatures info.
+	  break;
+
+	case 'O':
+	  outPath = opt_val;
+	  break;
+
+	case 'o':
+	  if ( longOpt ){
+	    if ( long_option == "occurrences" ){
+	      if ( opt_val == "train" )
+		occIn = 1;
+	      else if ( opt_val == "test" )
+		occIn = 2;
+	      else if ( opt_val == "both" )
+		occIn = 3;
+	      else {
+		Error( "invalid --ocurrences value. (expected train,test or both)" );
+		return false;
+	      }
+	    }
+	  }
+	  break;
+
+	case 'p':
+	  local_progress = TiCC::stringTo<int>( opt_val );
+	  break;
+
+	case 'q':
+	  threshold = TiCC::stringTo<int>( opt_val );
+	  break;
+
+	case 'Q':
+	  do_query = true;
+	  break;
+
+	case 'R':
+	  if ( !TiCC::stringTo<int>( opt_val, seed ) ){
+	    Error( "Integer argument for Random Seed expected (-R option)" );
+	    return false;
+	  }
+	  break;
+
+	case 's':
+	  if ( longOpt ){
+	    if ( long_option == "sloppy" ){
+	      bool val;
+	      if ( !isBoolOrEmpty(opt_val,val) ){
+		Error( "invalid value for sloppy: '"
+		       + opt_val + "'" );
+		return false;
+	      }
+	      do_sloppy_loo = val;
+	    }
+	    else if ( long_option == "silly" ){
+	      bool val;
+	      if ( !isBoolOrEmpty(opt_val,val) ){
+		Error( "invalid value for silly: '"
+		       + opt_val + "'" );
+		return false;
+	      }
+	      do_silly = val;
+	    }
+	  }
+	  else { //short opt, so -s
+	    if ( opt_val.empty() ){
+	      do_sample_weights = true;
+	    }
+	    else {
+	      int val;
+	      if ( TiCC::stringTo<int>( opt_val, val ) ){
+		if ( val == 0 ){
+		  do_ignore_samples = true;
+		  do_ignore_samples_test = false;
+		  do_sample_weights = true;
+		}
+		else if ( val == 1 ){
+		  do_ignore_samples_test = true;
+		  do_sample_weights = true;
+		}
+	      }
+	      if ( !do_sample_weights) {
+		Error( "invalid value for -s: '" + opt_val + "' (maybe you meant --s" + opt_val + " ?)" );
+		return false;
+	      }
+	    }
+	  }
+	  break;
+
+	case 't':
+	  {
+	    AlgorithmType tmp_a = IB1_a;
+	    if ( compare_nocase( opt_val, "leave_one_out" ) )
+	      tmp_a = LOO_a;
+	    else if ( compare_nocase( opt_val, "cross_validate" ) )
+	      tmp_a = CV_a;
+	    if ( local_algo != IB1_a && tmp_a != IB1_a ){
+	      Error( "only IB1 algorithm is allowed for: " + TiCC::toString(tmp_a)  );
+	      return false;
+	    }
+	    local_algo = tmp_a;
+	  }
+	  break;
+	case 'T': {
+	  if ( longOpt ){
+	    if ( long_option == "Threshold" ){
+	      if ( !TiCC::stringTo<int>(opt_val, igThreshold )
+		   || igThreshold < 0 ){
+		Error( "invalid value for Threshold: " + opt_val );
+		return false;
+	      }
+	    }
+	    else if ( long_option == "Treeorder" ){
+	      if ( !TiCC::stringTo<OrdeningType>( opt_val, local_order ) ){
+		Error( "invalid value for Treeorder: " + opt_val );
+		return false;
+	      }
+	    }
+	  }
+	  else if ( opt_val.find("hreshold") != string::npos ||
+		    opt_val.find("reeorder") != string::npos ){
+	    Error( "invalid option: Did you mean '--T" + opt_val + "' ?" );
+	    return false;
+	  }
+	  else if ( !TiCC::stringTo<int>( opt_val, target_pos )
+		    || target_pos <= 0 ){
+	    Error( "illegal value for -T option: " + opt_val );
 	    return false;
 	  }
 	}
-	else if ( myoptarg.find("hreshold") != string::npos ||
-		  myoptarg.find("reeorder") != string::npos ){
-	  Error( "invalid option: Did you mean '--T" + myoptarg + "' ?" );
-	  return false;
-	}
-	else if ( ! stringTo<int>( myoptarg, target_pos ) ){
-	  Error( "invalid option: Did you mean '-T value ?" );
-	  return false;
-	}
-	else if ( target_pos <= 0 ){
-	  Error( "illegal value for -T option: " + myoptarg );
-	  return false;
-	}
-      }
-	break;
+	  break;
 
-      case 'v':{
-	VerbosityFlags Flag = NO_VERB;
-	if ( !stringTo<VerbosityFlags>( myoptarg, Flag ) ){
-	  Error( "illegal value for +/- v option: " + myoptarg );
-	  return false;
-	}
-	else {
-	  if ( mode == 2 &&
-	       ( !(Flag & (SILENT|DISTANCE|DISTRIB|NEAR_N|CONF_MATRIX) ) ) )
+	case 'v':{
+	  VerbosityFlags Flag = NO_VERB;
+	  if ( !TiCC::stringTo<VerbosityFlags>( opt_val, Flag ) ){
+	    Error( "illegal value for +/- v option: " + opt_val );
 	    return false;
-	  else if ( Flag > 0 )
-	    if ( mood ){
-	      myVerbosity |= Flag;
+	  }
+	  else {
+	    if ( mode == 2 &&
+		 ( !(Flag & (SILENT|DISTANCE|DISTRIB|NEAR_N|CONF_MATRIX) ) ) ){
+	      Error( "-v option: " + TiCC::toString(Flag) +
+		     " is not allowed at this stage." );
+	      return false;
 	    }
-	    else {
-	      myVerbosity &= ~Flag;
-	    }
-	  else
-	    myVerbosity = NO_VERB;
+	    else if ( Flag > 0 )
+	      if ( mood ){
+		myVerbosity |= Flag;
+	      }
+	      else {
+		myVerbosity &= ~Flag;
+	      }
+	    else
+	      myVerbosity = NO_VERB;
+	  }
 	}
-      }
-	break;
+	  break;
 
-      case 'w': {
-	if ( !stringTo<WeightType>( myoptarg, local_weight ) )
-	  return false;
-      };
-      break;
+	case 'w': {
+	  if ( !TiCC::stringTo<WeightType>( opt_val, local_weight ) )
+	    return false;
+	};
+	  break;
 
-      case 'W': {
-	do_all_weights = true;
-      };
-      break;
+	case 'W': {
+	  do_all_weights = true;
+	};
+	  break;
 
-      case 'x':
-	do_exact = mood;
-	break;
+	case 'x':
+	  do_exact = mood;
+	  break;
 
-      }
+	default:
+	  Warning( string("unhandled option: ") + opt_char + " " + opt_val );
+	}
       }
       catch( std::runtime_error& err ) {
-	cerr << "invalid value for option '" << option << "'" << endl;
+	Error( string("invalid value for option '-") + opt_char + "' ("
+	       + opt_val + ")" );
 	return false;
       }
-      ++curr_opt;
     }
     return true;
   }
