@@ -1,30 +1,4 @@
 /*
-  $Id: IBtree.cxx 16820 2014-01-06 10:12:30Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/IBtree.cxx $
-
-  Copyright (c) 1998 - 2014
-  ILK   - Tilburg University
-  CLiPS - University of Antwerp
-
-  This file is part of timbl
-
-  timbl is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 3 of the License, or
-  (at your option) any later version.
-
-  timbl is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, see <http://www.gnu.org/licenses/>.
-
-  For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
-  or send mail to:
-      timbl@uvt.nl
 */
 #include <string>
 #include <vector>
@@ -46,7 +20,6 @@
 #include "timbl/IBtree.h"
 
 using namespace std;
-using namespace TiCC;
 
 namespace Timbl {
   using namespace Common;
@@ -274,20 +247,20 @@ namespace Timbl {
   }
 
   xmlNode *to_node( const FeatureValue *fv ){
-    xmlNode *result = XmlNewNode( "feature" );
-    XmlAddContent( result, fv->Name() );
+    xmlNode *result = TiCC::XmlNewNode( "feature" );
+    TiCC::XmlAddContent( result, fv->Name() );
     return result;
   }
 
   xmlNode *to_node( const TargetValue *tv ){
-    xmlNode *result = XmlNewNode( "target" );
-    XmlAddContent( result, tv->Name() );
+    xmlNode *result = TiCC::XmlNewNode( "target" );
+    TiCC::XmlAddContent( result, tv->Name() );
     return result;
   }
 
   xmlNode *to_node( const ValueDistribution *d ){
-    xmlNode *result = XmlNewNode( "distribution" );
-    XmlAddContent( result, d->DistToString() );
+    xmlNode *result = TiCC::XmlNewNode( "distribution" );
+    TiCC::XmlAddContent( result, d->DistToString() );
     return result;
   }
 
@@ -309,11 +282,11 @@ namespace Timbl {
   }
 
   xmlNode *to_xml( IBtree *pnt ) {
-    xmlNode *nodes = XmlNewNode( "nodes" );
+    xmlNode *nodes = TiCC::XmlNewNode( "nodes" );
     int cnt = count_next( pnt );
-    XmlSetAttribute( nodes, "nodecount", toString( cnt ) );
+    TiCC::XmlSetAttribute( nodes, "nodecount", TiCC::toString( cnt ) );
     while ( pnt ){
-      xmlNode *node = XmlNewChild( nodes, "node" );
+      xmlNode *node = TiCC::XmlNewChild( nodes, "node" );
       if ( pnt->FValue )
 	xmlAddChild( node, to_node( pnt->FValue ) );
       if ( pnt->TValue )
@@ -333,9 +306,10 @@ namespace Timbl {
 
   void InstanceBase_base::toXML( ostream &os )  {
     // save an IBtree for later use.
-    XmlDoc doc( "root" );
+    TiCC::XmlDoc doc( "root" );
     xmlNode *root = doc.getRoot();
-    xmlAddChild( root, XmlNewComment( "Version " + toString(Version) ) );
+    xmlAddChild( root,
+		 TiCC::XmlNewComment( "Version " + TiCC::toString(Version) ) );
     bool dummy;
     xmlAddChild( root, to_node( TopTarget( dummy ) ) );
     if ( PersistentDistributions )
@@ -348,10 +322,8 @@ namespace Timbl {
 
   string toString( const vector<FeatureValue*> vec ){
     string result;
-    vector<FeatureValue*>::const_iterator it = vec.begin();
-    while ( it != vec.end() ){
-      result += " " + (*it)->Name();
-      ++it;
+    for ( auto const& fv : vec ){
+      result += " " + fv->Name();
     }
     return result;
   }
@@ -998,6 +970,7 @@ namespace Timbl {
     TopDistribution( new ValueDistribution ),
     WTop( 0 ),
     TopT( 0 ),
+    tiedTop(false),
     InstBase( 0 ),
     LastInstBasePos( 0 ),
     RestartSearch( new const IBtree *[depth] ),
