@@ -1,11 +1,9 @@
 /*
-  $Id: LOOExperiment.cxx 16820 2014-01-06 10:12:30Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/LOOExperiment.cxx $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
- 
+
   This file is part of timbl
 
   timbl is free software; you can redistribute it and/or modify
@@ -22,40 +20,29 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
 */
 
-
 #include <string>
 #include <map>
 #include <fstream>
-#include <sstream>
-#include <iomanip>
 #include <cassert>
-#include <cstdlib>
 
 #include <sys/time.h>
 
 #include "timbl/MsgClass.h"
 #include "timbl/Common.h"
 #include "timbl/Types.h"
-#include "timbl/Options.h"
-#include "timbl/Instance.h"
-#include "timbl/Statistics.h"
-#include "timbl/neighborSet.h"
-#include "timbl/BestArray.h"
 #include "timbl/IBtree.h"
 #include "timbl/MBLClass.h"
 #include "timbl/TimblExperiment.h"
 
-using namespace TiCC;
-
 namespace Timbl {
   using namespace std;
 
-  void LOO_Experiment::initExperiment( bool all_vd ){ 
+  void LOO_Experiment::initExperiment( bool all_vd ){
     if ( !ExpInvalid() ){
       if ( !MBL_init ){  // do this only when necessary
 	initDecay();
@@ -65,8 +52,8 @@ namespace Timbl {
 	    calculatePrestored();
 	  else {
 	    Error( string("not enough memory for Probability Arrays")
-		   + "' in (" 
-		   + __FILE__  + "," + toString(__LINE__) + ")\n"
+		   + "' in ("
+		   + __FILE__  + "," + TiCC::toString(__LINE__) + ")\n"
 		   + "ABORTING now" );
 	    throw std::bad_alloc();
 	  }
@@ -80,7 +67,7 @@ namespace Timbl {
       }
     }
   }
-  
+
   bool LOO_Experiment::checkTestFile(){
     // no need to test the Testfile
     // it is the same as the trainfile, so already checked
@@ -112,6 +99,10 @@ namespace Timbl {
 			     const string& OutFile ){
     bool result = false;
     if ( initTestFiles( FileName, OutFile ) ){
+      if ( InstanceBase->nodeCount() == InstanceBase->depth() + 1 ){
+	// protect ourselves against 1-line trainfiles
+	FatalError( "the file '" + FileName + "' contains only 1 usable line. LOO impossible!" );
+      }
       initExperiment();
       stats.clear();
       delete confusionInfo;
@@ -130,8 +121,8 @@ namespace Timbl {
       string Buffer;
       while ( nextLine( testStream, Buffer ) ){
 	if ( !chopLine( Buffer ) ) {
-	  Warning( "testfile, skipped line #" + 
-		   toString<int>( stats.totalLines() ) +
+	  Warning( "testfile, skipped line #" +
+		   TiCC::toString<int>( stats.totalLines() ) +
 		   "\n" + Buffer );
 	}
 	else {
@@ -139,7 +130,7 @@ namespace Timbl {
 	  Decrement( CurrInst );
 	  double final_distance = 0.0;
 	  bool exact = false;
-	  const TargetValue *ResultTarget = LocalClassify( CurrInst, 
+	  const TargetValue *ResultTarget = LocalClassify( CurrInst,
 							   final_distance,
 							   exact );
 	  normalizeResult();
@@ -148,7 +139,7 @@ namespace Timbl {
 	  if ( Verbosity(CONFIDENCE) )
 	    confidence = bestResult.confidence( ResultTarget );
 	  // Write it to the output file for later analysis.
-	  show_results( outStream, confidence, dString, 
+	  show_results( outStream, confidence, dString,
 			ResultTarget, final_distance );
 	  if ( exact ){ // remember that a perfect match may be incorrect!
 	    if ( Verbosity(EXACT) ) {
@@ -176,5 +167,5 @@ namespace Timbl {
     Error( "cannot combine Leave One Out with retrieving an Instancebase " );
     return false;
   }
-  
+
 }
