@@ -1,11 +1,9 @@
 /*
-  $Id: Statistics.cxx 16820 2014-01-06 10:12:30Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/Statistics.cxx $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
- 
+
   This file is part of timbl
 
   timbl is free software; you can redistribute it and/or modify
@@ -22,9 +20,9 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
 */
 
 #include <iostream>
@@ -55,17 +53,17 @@ namespace Timbl {
     }
     catch( bad_alloc ){
       Error ( "Not enough memory for ConfusionMatrix" );
-      throw;      
+      throw;
     }
   }
-  
+
   ConfusionMatrix::~ConfusionMatrix(){
     for ( unsigned int i=0; i <= size; ++i )
       mat[i].clear();
     mat.clear();
   }
-  
-  void ConfusionMatrix::Increment( const TargetValue *t1, 
+
+  void ConfusionMatrix::Increment( const TargetValue *t1,
 				   const TargetValue *t2 ){
     if ( t2 ){
       if ( t1 )
@@ -76,49 +74,50 @@ namespace Timbl {
     else
       throw std::out_of_range( "ConfusionMatrix, index out of range" );
   }
-  
+
   void ConfusionMatrix::Print( ostream& os, const Target *tg ) const {
     os << "Confusion Matrix:" << endl;
     os << "        ";
-    for ( unsigned int i=0; i < tg->ValuesArray.size(); ++i ){
+    for ( const auto& val : tg->ValuesArray ){
       // Print the class names.
       os.width(6);
       os.setf(ios::right, ios::adjustfield);
-      os << tg->ValuesArray[i] << " ";
+      os << val << " ";
     }
     os << endl;
     os << "        ";
-    for ( unsigned int i=0; i < size; ++i )
+    for ( unsigned int i=0; i < size; ++i ){
       os << "-------";
+    }
     os << endl;
     for ( unsigned int i=0; i < tg->ValuesArray.size(); ++i ){
       os.width(6);
       os.setf(ios::right, ios::adjustfield);
       os << tg->ValuesArray[i] << " | ";
-      for ( unsigned int j=0; j < size; ++j ){
+      for ( const auto& mv : mat[i] ){
 	os.width(6);
 	os.setf(ios::right, ios::adjustfield);
-	os << mat[i][j] << " ";
+	os << mv << " ";
       }
       os << endl;
       if ( i == tg->ValuesArray.size() - 1 ){
 	os <<  "   -*- | ";
-	for ( unsigned int j=0; j < size; ++j ){
+	for ( const auto& mv : mat[size] ){
 	  os.width(6);
 	  os.setf(ios::right, ios::adjustfield);
-	  os << mat[size][j] << " ";
+	  os << mv << " ";
 	}
 	os << endl;
       }
     }
     os << endl;
   }
-  
+
   void pf( ostream& os, size_t d ){
     os.width(4);
     os << " \t" << d;
   }
-  
+
   void pf( ostream& os, double d ){
     if ( d < 0 )
       os << " \t (nan)\t";
@@ -127,8 +126,8 @@ namespace Timbl {
       os << " \t" << d;
     }
   }
-  
-  void ConfusionMatrix::FScore( ostream& os, 
+
+  void ConfusionMatrix::FScore( ostream& os,
 				const Target* tg, bool cs_too ) const {
     double maf = 0.0;
     double mif = 0.0;
@@ -202,7 +201,7 @@ namespace Timbl {
 	AUC = -1;
       }
       else {
-	AUC = ( 0.5 * TPR * FPR ) + ( TPR * ( 1.0 - FPR ) ) + 
+	AUC = ( 0.5 * TPR * FPR ) + ( TPR * ( 1.0 - FPR ) ) +
 	  ( 0.5 * ( ( 1.0 - TPR ) * ( 1.0 - FPR ) ) );
 	++effA;
 	maa += AUC;
@@ -253,5 +252,5 @@ namespace Timbl {
     _tieFalse += in._tieFalse;
     _exact += in._exact;
   }
-  
+
 }
