@@ -1,11 +1,9 @@
 /*
-  $Id: StringOps.cxx 16820 2014-01-06 10:12:30Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/StringOps.cxx $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
- 
+
   This file is part of timbl
 
   timbl is free software; you can redistribute it and/or modify
@@ -22,9 +20,9 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
 */
 
 #include <algorithm>
@@ -38,7 +36,7 @@
 
 using namespace std;
 namespace Timbl {
-  
+
   string StrToCode( const string &par ){
     string In = TiCC::trim(par);
     string Out;
@@ -64,7 +62,7 @@ namespace Timbl {
     }
     return Out;
   }
-  
+
   string CodeToStr( const string& in ){
     string out;
     string::const_iterator it = in.begin();
@@ -98,28 +96,11 @@ namespace Timbl {
     }
     return out;
   }
-  
-  string string_tok( const string& s, 
-		     string::size_type& pos,
-		     const string& seps ){
-    string::size_type b_pos = s.find_first_not_of( seps, pos ); 
-    if ( b_pos != string::npos ){
-      pos = s.find_first_of( seps, b_pos ); 
-      if ( pos == string::npos )
-	return string( s, b_pos );
-      else
-	return string( s, b_pos, pos - b_pos );
-    }
-    else {
-      pos = string::npos;
-    }
-    return "";
-  }
-  
+
   bool nocase_cmp( char c1, char c2 ){
     return toupper(c1) == toupper(c2);
   }
-  
+
   bool compare_nocase( const string& s1, const string& s2 ){
     if ( s1.size() == s2.size() &&
 	 equal( s1.begin(), s1.end(), s2.begin(), nocase_cmp ) )
@@ -127,7 +108,7 @@ namespace Timbl {
     else
       return false;
   }
-  
+
   bool compare_nocase_n( const string& s1, const string& s2 ){
     if ( s1.size() <= s2.size() &&
 	 equal( s1.begin(), s1.end(), s2.begin(), nocase_cmp ) )
@@ -136,4 +117,36 @@ namespace Timbl {
       return false;
   }
 
+  string correct_path( const string& filename,
+		       const string& path,
+		       bool keep_origpath ){
+    // if filename contains pathinformation, it is replaced with path, except
+    // when keep_origpath is true.
+    // if filename contains NO pathinformation, path is always appended.
+    // of course we don't append if the filename is empty or just '-' !
+
+    if ( path != "" && filename != "" && filename[0] != '-' ){
+      bool add_slash = path.back() != '/';
+      string result = path;
+      if ( add_slash ){
+	  result += "/";
+      }
+      string::size_type pos = filename.rfind( '/' );
+      if ( pos == string::npos ){
+	result += filename;
+      }
+      else {
+	if ( keep_origpath ){
+	  result += filename;
+	}
+	else{
+	  result += filename.substr( pos+1 );
+	}
+      }
+      return result;
+    }
+    else
+      return filename;
+  }
+
 } // namespace Timbl
