@@ -1,9 +1,7 @@
 /*
-  $Id: Timbl.cxx 16820 2014-01-06 10:12:30Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/Timbl.cxx $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
   ILK   - Tilburg University
+  CLST  - Radboud University
   CLiPS - University of Antwerp
 
   This file is part of timbl
@@ -22,9 +20,9 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/timbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
 */
 
 #include <exception>
@@ -40,11 +38,11 @@
 #include <cctype>
 
 #include "config.h"
+#include "ticcutils/CommandLine.h"
 #include "timbl/TimblAPI.h"
 
 using namespace std;
 using namespace Timbl;
-using namespace TiCC;
 
 static list<string> ind_lines;
 
@@ -174,8 +172,8 @@ inline void usage_full(void){
   cerr << "-p n      : show progress every n lines (default p = 100,000)"
        << endl;
   cerr << "-U f      : save value_class probabilities in file 'f'" << endl;
-  cerr << "-V        : Show VERSION" << endl;
-  cerr << "+v or -v level : set or unset verbosity level, where level is"
+  cerr << "-V or --version : Show VERSION" << endl;
+  cerr << "+v or -v level  : set or unset verbosity level, where level is"
        << endl;
   cerr << "      s:  work silently" << endl;
   cerr << "      o:  show all options set" << endl;
@@ -213,7 +211,7 @@ inline void usage_full(void){
   cerr << "-O d      : save output using path 'd'" << endl;
   cerr << "Internal representation options:" << endl;
   cerr << "-B n      : number of bins used for discretization of numeric "
-       << "feature values" << endl;
+       << "feature values (default B=20)" << endl;
   cerr << "-c n      : clipping frequency for prestoring MVDM matrices"
        << endl;
   cerr << "+D        : store distributions on all nodes" << endl
@@ -254,7 +252,7 @@ inline void usage(void){
 
 void get_command_lines( const string& value, list<string>& result ){
   result.clear();
-  ifstream ind( value.c_str()+1 ); // skip @
+  ifstream ind( value.substr(1) ); // skip @
   if ( ind.bad() ){
     cerr << "Problem reading command-lines from file '"
 	 << value << "'" << endl;
@@ -268,76 +266,42 @@ void get_command_lines( const string& value, list<string>& result ){
   }
 }
 
-string correct_path( const string& filename,
-		     const string& path,
-		     bool keep_origpath ){
-  // if filename contains pathinformation, it is replaced with path, except
-  // when keep_origpath is true.
-  // if filename contains NO pathinformation, path is always appended.
-  // of course we don't append if the filename is empty or just '-' !
-
-  if ( path != "" && filename != "" && filename[0] != '-' ){
-    bool add_slash = path[path.length()] != '/';
-    string tmp;
-    string::size_type pos = filename.rfind( '/' );
-    if ( pos == string::npos ){
-      tmp = path;
-      if ( add_slash )
-	tmp += "/";
-      tmp += filename;
-    }
-    else {
-      tmp = path;
-      if ( add_slash )
-	tmp += "/";
-      if ( !keep_origpath ){
-	tmp += filename.substr( pos+1 );
-      }
-      else
-	tmp += filename;
-    }
-    return tmp;
-  }
-  else
-    return filename;
-}
-
 class softExit : public exception {};
+class hardExit : public exception {};
 
-void Preset_Values( TimblOpts& Opts ){
-  bool mood;
+void Preset_Values( TiCC::CL_Options& opts ){
   string value;
-  if ( Opts.Find( 'h', value, mood ) ){
+  if ( opts.is_present( 'h' )
+       || opts.is_present( "help" ) ){
     usage_full();
     throw( softExit() );
   }
-  if ( Opts.Find( 'V', value, mood ) ){
+  if ( opts.is_present( 'V' )
+       || opts.is_present( "version" ) ){
     cerr << "TiMBL " << Timbl::BuildInfo() << endl;
     throw( softExit() );
   }
-  if ( Opts.Find( 'S', value, mood ) ){
+  if ( opts.is_present( 'S' ) ){
     cerr << "Server mode is no longer available in timbl" << endl;
     cerr << "Please use the 'timblserver' command instead." << endl;
-    throw( softExit() );
+    throw( hardExit() );
   }
-  if ( Opts.Find( 'a', value, mood ) ){
+  if ( opts.extract( 'a', value ) ){
     // the user gave an algorithm
     if ( !string_to( value, algorithm ) ){
       cerr << "illegal -a value: " << value << endl;
-      throw( softExit() ); // no chance to proceed
+      throw( hardExit() ); // no chance to proceed
     }
-    Opts.Delete( 'a' );
   }
   else
     algorithm = IB1; // general default
-  Opts.Add( 'a', to_string( algorithm ), false );
-  if ( Opts.Find( 'Z', value, mood ) ){
+  opts.insert( 'a', to_string( algorithm ), false );
+  if ( opts.extract( 'Z', value ) ){
     // Special case
     //    spitting neigborSets only
     Do_NS = true;
-    Opts.Delete( 'Z' );
   }
-  if ( Opts.Find( 't', value, mood ) ){
+  if ( opts.is_present( 't', value ) ){
     if ( value == "cross_validate" )
       // Special case
       //    running Cross Validation
@@ -348,56 +312,50 @@ void Preset_Values( TimblOpts& Opts ){
       Do_LOO = true;
     else if ( value != "" && value[0] == '@' ){
       Do_Indirect = true;
+      opts.remove( 't' );
       get_command_lines( value, ind_lines );
-      Opts.Delete( 't' );
     }
     if ( Do_LOO || Do_CV )
       if ( algorithm != IB1 ){
 	cerr << "Invalid Algorithm: Only IB1 possible for LOO and CV " << endl;
-	throw( softExit() ); // no chance to proceed
+	throw( hardExit() ); // no chance to proceed
       }
   }
-  if ( Opts.Find( 'P', value, mood ) ){
+  if ( opts.extract( 'P', value ) ){
     I_Path = value;
-    Opts.Delete( 'P' );
   }
-  if ( Opts.Find( 'O', value, mood ) ){
+  if ( opts.is_present( 'O', value ) ){
     // output path is needed for CV testing
     O_Path = value;
   }
-  if ( Opts.Find( 'f', value, mood ) ){
-    dataFile = correct_path( value, I_Path, true );
-    Opts.Delete( 'f' );
+  if ( opts.extract( 'f', value ) ){
+    dataFile = correct_path( value, I_Path );
   }
-  if ( Opts.Find( 'q', value, mood ) ){
-    Q_value = value;
-  }
-  Opts.Add( 'v', "F", true );
-  Opts.Add( 'v', "S", false );
+  opts.is_present( 'q', Q_value );
+  opts.insert( 'v', "F", true );
+  opts.insert( 'v', "S", false );
   Weighting W = GR;
   // default Weighting = GainRatio
-  if ( Opts.Find( 'w', value, mood ) ){
+  if ( opts.is_present( 'w', value ) ){
     // user specified weighting
     if ( !string_to( value, W ) )
       // no valid weight, hopefully a filename
       return;
     else
       // valid Weight, but maybe a number, so replace
-      Opts.Delete( 'w' );
+      opts.remove( 'w' );
   }
-  Opts.Add( 'w', to_string(W), false );
+  opts.insert( 'w', to_string(W), false );
 }
 
-void Adjust_Default_Values( TimblOpts& Opts ){
-  bool mood;
+void Adjust_Default_Values( TiCC::CL_Options& opts ){
   string value;
-  if ( !Opts.Find( 'm', value, mood ) ){
-    Opts.Add( 'm', "O", false );
+  if ( !opts.is_present( 'm' ) ){
+    opts.insert( 'm', "O", false );
     // Default Metric = Overlap
   }
-  if ( Opts.Find( '%', value, mood ) ){
+  if ( opts.extract( '%' ) ){
     Do_Save_Perc = true;
-    Opts.Delete( '%' );
   }
 }
 
@@ -412,7 +370,7 @@ bool next_test( string& line ){
   return result;
 }
 
-bool get_file_names( TimblOpts& Opts ){
+bool get_file_names( TiCC::CL_Options& opts ){
   TestFile = "";
   OutputFile = "";
   PercFile = "";
@@ -430,9 +388,7 @@ bool get_file_names( TimblOpts& Opts ){
   ProbOutFile = "";
   NamesFile = "";
   string value;
-  bool mood;
-  if ( Opts.Find( 'P', value, mood ) ||
-       Opts.Find( 'f', value, mood ) ){
+  if ( opts.extract( 'P', value ) || opts.extract( 'f', value ) ){
     cerr << "illegal option, value = " << value << endl;
     return false;
   }
@@ -450,70 +406,59 @@ bool get_file_names( TimblOpts& Opts ){
     }
     TestFile = dataFile;
   }
-  else if ( Opts.Find( 't', value, mood ) ){
-    TestFile = correct_path( value, I_Path, true );
-    Opts.Delete( 't' );
+  else if ( opts.extract( 't', value ) ){
+    TestFile = correct_path( value, I_Path );
   }
-  if ( Opts.Find( 'n', value, mood ) ){
-    NamesFile = correct_path( value, O_Path, true );
-    Opts.Delete( 'n' );
+  if ( opts.extract( 'n', value ) ){
+    NamesFile = correct_path( value, O_Path );
   }
-  if ( Opts.Find( "matrixout", value ) ){
-    MatrixOutFile = correct_path( value, O_Path, true );
-    Opts.Delete( "matrixout" );
+  if ( opts.extract( "matrixout", value ) ){
+    MatrixOutFile = correct_path( value, O_Path );
   }
-  if ( Opts.Find( "matrixin", value ) ){
-    MatrixInFile = correct_path( value, I_Path, true );
-    Opts.Delete( "matrixin" );
+  if ( opts.extract( "matrixin", value ) ){
+    MatrixInFile = correct_path( value, I_Path );
   }
-  if ( Opts.Find( 'o', value, mood ) ){
+  if ( opts.extract( 'o', value ) ){
     if ( Do_CV ){
       cerr << "-o option not possible for Cross Validation testing" << endl;
       return false;
     }
-    OutputFile = correct_path( value, O_Path, true );
-    Opts.Delete( 'o' );
+    OutputFile = correct_path( value, O_Path );
   }
-  if ( Opts.Find( "IL", value ) ){
+  if ( opts.extract( "IL", value ) ){
     vector<string> vec;
     int num = TiCC::split_at( value, vec, ":" );
     if ( num > 1 ){
-      levelTreeOutFile = correct_path( vec[0], O_Path, true );
-      levelTreeLevel = stringTo<int>( vec[1] );
+      levelTreeOutFile = correct_path( vec[0], O_Path );
+      levelTreeLevel = TiCC::stringTo<int>( vec[1] );
     }
     else
-      levelTreeOutFile = correct_path( value, O_Path, true );
-    Opts.Delete( "IL" );
+      levelTreeOutFile = correct_path( value, O_Path );
   }
-  if ( Opts.Find( 'I', value, mood ) ){
-    TreeOutFile = correct_path( value, O_Path, true );
-    Opts.Delete( 'I' );
+  if ( opts.extract( 'I', value ) ){
+    TreeOutFile = correct_path( value, O_Path );
   }
-  if ( Opts.Find( 'X', value, mood ) ){
-    XOutFile = correct_path( value, O_Path, true );
-    Opts.Delete( 'X' );
+  if ( opts.extract( 'X', value ) ){
+    XOutFile = correct_path( value, O_Path );
   }
-  if ( Opts.Find( 'i', value, mood ) ){
-    TreeInFile = correct_path( value, I_Path, true );
-    Opts.Delete( 'i' );
+  if ( opts.extract( 'i', value ) ){
+    TreeInFile = correct_path( value, I_Path );
   }
-  if ( Opts.Find( 'U', value, mood ) ){
-    ProbOutFile = correct_path( value, O_Path, true );
-    Opts.Delete( 'U' );
+  if ( opts.extract( 'U', value ) ){
+    ProbOutFile = correct_path( value, O_Path );
   }
-  if ( Opts.Find( 'u', value, mood ) ){
+  if ( opts.extract( 'u', value ) ){
     if ( algorithm == IGTREE ){
       cerr << "-u option is useless for IGtree" << endl;
       return false;
     }
-    ProbInFile = correct_path( value, I_Path, true );
-    Opts.Delete( 'u' );
+    ProbInFile = correct_path( value, I_Path );
   }
-  if ( Opts.Find( 'W', value, mood ) ){
-    WgtOutFile = correct_path( value, O_Path, true );
+  if ( opts.is_present( 'W', value ) ){
+    WgtOutFile = correct_path( value, O_Path );
     // leave the option, to signal that we need ALL feature weights
   }
-  if ( Opts.Find( 'w', value, mood ) ){
+  if ( opts.is_present( 'w', value ) ){
     Weighting W;
     if ( !string_to( value, W ) ){
       // No valid weighting, so assume it also has a filename
@@ -524,13 +469,13 @@ bool get_file_names( TimblOpts& Opts ){
 	  cerr << "invalid weighting option: " << value << endl;
 	  return false;
 	}
-	WgtInFile = correct_path( parts[0], I_Path, true );
+	WgtInFile = correct_path( parts[0], I_Path );
 	WgtType = W;
-	Opts.Delete( 'w' );
+	opts.remove( 'w' );
       }
       else if ( num == 1 ){
-	WgtInFile = correct_path( value, I_Path, true );
-	Opts.Delete( 'w' );
+	WgtInFile = correct_path( value, I_Path );
+	opts.remove( 'w' );
       }
       else {
 	cerr << "invalid weighting option: " << value << endl;
@@ -541,9 +486,8 @@ bool get_file_names( TimblOpts& Opts ){
   return true;
 }
 
-bool Default_Output_Names( TimblOpts& Opts ){
+bool Default_Output_Names( TiCC::CL_Options& opts ){
   string value;
-  bool mood;
   if ( OutputFile == "" && TestFile != "" ){
     string temp = correct_path( TestFile, O_Path, false );
     temp += ".";
@@ -585,18 +529,18 @@ bool Default_Output_Names( TimblOpts& Opts ){
     }
     if ( algorithm != IGTREE ){
       temp +=  ".";
-      if ( Opts.Find( 'm', value, mood ) )
-	temp +=  value;
+      if ( opts.is_present( 'm', value ) )
+	temp += value;
       else
 	temp +=  "ErRoR";
-      if ( Opts.Find( 'L', value, mood ) ){
-	temp +=  ".L";
-	temp +=  value;
+      if ( opts.is_present( 'L', value ) ){
+	temp += ".L";
+	temp += value;
       }
     }
     temp +=  ".";
-    if ( Opts.Find( 'w', value, mood ) ){
-      temp +=  value;
+    if ( opts.is_present( 'w', value ) ){
+      temp += value;
     }
     else
       if ( !WgtInFile.empty() )
@@ -604,18 +548,19 @@ bool Default_Output_Names( TimblOpts& Opts ){
       else
 	temp += "gr";
     if ( algorithm != IGTREE ){
-      if ( Opts.Find( 'k', value, mood ) ){
+      if ( opts.is_present( 'k', value ) ){
 	temp +=  ".k";
 	temp +=  value;
       }
       else
 	temp +=  ".k1";
-      if ( Opts.Find( 'd', value, mood ) ){
+      if ( opts.is_present( 'd', value ) ){
 	temp +=  ".";
 	temp +=  value;
       }
     }
-    if ( Opts.Find( 'x', value, mood ) ){
+    bool mood;
+    if ( opts.is_present( 'x', value, mood ) ){
       if ( mood ){
 	temp +=  ".X";
       }
@@ -659,16 +604,25 @@ void Do_Test( TimblAPI *Run ){
     // multiple tests from indirect file
     string tmp_line;
     while ( next_test( tmp_line) ){
-      TimblOpts Opts( tmp_line );
-      Adjust_Default_Values( Opts );
-      if ( !get_file_names( Opts ) || TestFile == "" ){
+      TiCC::CL_Options opts( timbl_indirect_opts, "" );
+      try {
+	opts.init( tmp_line );
+	Adjust_Default_Values( opts );
+      }
+      catch ( TiCC::OptionError& e ){
+	cerr << e.what() << endl;
+	cerr << "Warning: Skipped a line from indirect testfile:\n'"
+	     << tmp_line << "'" << endl;
+	continue;
+      }
+      if ( !get_file_names( opts ) || TestFile == "" ){
 	cerr << "Warning: Skipped a line from indirect testfile:\n'"
 	     << tmp_line << "'" << endl;
 	if ( TestFile == "" )
 	  cerr << "missing a Testfile name " << endl;
       }
-      else if ( Run->SetIndirectOptions( Opts ) ){
-	Default_Output_Names( Opts );
+      else if ( Run->SetIndirectOptions( opts ) ){
+	Default_Output_Names( opts );
 	if ( WgtInFile != "" ) {
 	  if ( !Run->GetWeights( WgtInFile, WgtType ) )
 	    continue;
@@ -694,7 +648,7 @@ void Do_Test( TimblAPI *Run ){
 
 bool checkInputFile( const string& name ){
   if ( !name.empty() ){
-    ifstream is( name.c_str() );
+    ifstream is( name );
     if ( !is.good() ){
       cerr << "unable to find or use input file '" << name << "'" << endl;
       return false;
@@ -705,7 +659,7 @@ bool checkInputFile( const string& name ){
 
 bool checkOutputFile( const string& name ){
   if ( !name.empty() ){
-    ofstream os( name.c_str() );
+    ofstream os( name );
     if ( !os.good() ) {
       cerr << "unable to find or use output file"  << name << "'" << endl;
       return false;
@@ -721,8 +675,9 @@ int main(int argc, char *argv[]){
     // Start.
     //
     cerr << "TiMBL " << TimblAPI::VersionInfo()
-	 << " (c) ILK 1998 - 2014.\n"
+	 << " (c) CLST/ILK/CLIPS 1998 - 2016.\n"
 	 << "Tilburg Memory Based Learner\n"
+	 << "Centre for Language and Speech Technology, Radboud University\n"
 	 << "Induction of Linguistic Knowledge Research Group, Tilburg University\n"
 	 << "CLiPS Computational Linguistics Group, University of Antwerp" << endl;
     time(&Time);
@@ -732,18 +687,32 @@ int main(int argc, char *argv[]){
       usage();
       return 1;
     }
-    TimblOpts Opts( argc, argv );
-    Preset_Values( Opts );
-    Adjust_Default_Values( Opts );
-    if ( !get_file_names( Opts ) )
+    TiCC::CL_Options opts( timbl_short_opts, timbl_long_opts );
+    try {
+      opts.init( argc, argv );
+    }
+    catch ( TiCC::OptionError& e ){
+      cerr << e.what() << endl;
+      usage();
+      return 666;
+    }
+    Preset_Values( opts );
+    Adjust_Default_Values( opts );
+    if ( !get_file_names( opts ) )
       return 2;
-    TimblAPI *Run = new TimblAPI( &Opts );
+    TimblAPI *Run = new TimblAPI( opts );
     if ( !Run->isValid() ){
       delete Run;
       usage();
       return 3;
     }
-    Default_Output_Names( Opts );
+    Default_Output_Names( opts );
+    vector<string> mas = opts.getMassOpts();
+    if ( !mas.empty() ){
+      cerr << "unknown value in option string: " << mas[0] << endl;
+      usage();
+      return 33;
+    }
     if ( Do_CV ){
       if ( checkInputFile( TestFile ) ){
 	Run->CVprepare( WgtInFile, WgtType, ProbInFile );
@@ -855,24 +824,24 @@ int main(int argc, char *argv[]){
 	}
       }
       delete Run;
+      if ( !do_test || !Run->isValid() ){
+	return EXIT_FAILURE;
+      }
     }
-    return 0;
+    return EXIT_SUCCESS;
+  }
+  catch( softExit& e ){
+    return EXIT_SUCCESS;
+  }
+  catch(std::string& what){
+    cerr << what << ", sorry" << endl;
   }
   catch(std::bad_alloc){
     cerr << "ran out of memory somewhere" << endl;
     cerr << "timbl terminated, Sorry for that" << endl;
   }
-  catch( softExit& e ){
-    return 0;
-  }
-  catch(std::string& what){
-    cerr << what << ", sorry" << endl;
-  }
   catch(std::exception& e){
     cerr << e.what() << ", sorry" << endl;
   }
-  catch(...){
-    cerr << "some exception was raised" << endl;
-    cerr << "timbl terminated, Sorry for that" << endl;
-  }
+  return EXIT_FAILURE;
 }
